--******************************************************************************************************************************
--* Licensed Materials - Property of IBM                                                                                       *
--* (c) Copyright IBM Corp. 2008, 2009 All Rights Reserved.                                                                    *
--*                                                                                                                            *
--*US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp*
--******************************************************************************************************************************

--=============  Create the model for NF schema 

USE $(DBNAME)
 GO
CREATE SCHEMA AUTHORIZATION $(NF_SCHEMA)
GO

CREATE TABLE $(NF_SCHEMA).CUSTOMER (
		CUSTOMER_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Customer Name Missing' NOT NULL,
		CUST_REFID NVARCHAR(100),
		COMPANY_NAME NVARCHAR(255),
		GEO_LOCATION NVARCHAR(255),
		CONTACT_EMAIL NVARCHAR(255),
		CONTACT_PHONE NVARCHAR(255),
		CONTACT_FAX NVARCHAR(255),
		CONTACT_ADDRESS NVARCHAR(255),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ACTIVITY (
		ACTIVITY_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Missing Acivity Name' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		ACTIVITY_CLASS_ID INT  DEFAULT -1 NOT NULL,
		TASK_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		FAILED_BUILD INT  DEFAULT -1 NOT NULL,
		CREATION_DATE DATETIME,
		VALIDATION_BUILD INT  DEFAULT -1 NOT NULL,
		NOTEST_BUILD INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		FILE_STREAM_ID INT  DEFAULT -1 NOT NULL,
		ACTIVITY_STATE NVARCHAR(255),
		PRIORITY NVARCHAR(255),
		STATUS NVARCHAR(255),
		RESOLUTION NVARCHAR(255),
		ACTIVITY_TYPE NVARCHAR(255),
		RESOLUTION_CODE NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ACTIVITY_CLASSIFICATION (
		ACTIVITY_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Activity Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_ACTIVITY_LOOKUP(
		REQUEST_ID INT  NOT NULL,
		ACTIVITY_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).COMPONENT (
		COMPONENT_ID INT  NOT NULL,
		COMPONENT_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Component Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PRODUCT_ID INT  DEFAULT -1 NOT NULL,
		PARENT_COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_COMPONENT_LOOKUP (
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		COMPONENT_ID INT  DEFAULT -1 NOT NULL
	) ON VNF_32K 
GO

	
CREATE TABLE $(NF_SCHEMA).COMPONENT_CLASSIFICATION (
		COMPONENT_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Component Class Name Missing' NOT NULL
	) ON VNF_32K 
GO

	
CREATE TABLE $(NF_SCHEMA).BUILD_CLASSIFICATION (
		BUILD_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Component Class Name Missing' NOT NULL
	) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).BUILD (
		BUILD_ID INT  NOT NULL,
		BUILD_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Build Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		BASELINE_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_TYPE_ID INT  DEFAULT -1 NOT NULL,
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		TEAM_ID INT  DEFAULT -1 NOT NULL,
		BUILD_STATE NVARCHAR(255),
		STATUS NVARCHAR(255),
		START_TIME DATETIME,
		END_TIME DATETIME,
		BUILD_TYPE NVARCHAR(255),
		CREATION_DATE DATETIME,
		WAITING_TIME INT ,        
		BUILDING_TIME INT ,        
		ENGINE NVARCHAR(255),		
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT (
		REQUIREMENT_ID INT  NOT NULL,
		REQUIREMENT_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Requirement Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		PLANNED_ITERATION_ID INT  DEFAULT -1 NOT NULL,
		ACTUAL_ITERATION_ID INT  DEFAULT -1 NOT NULL,
		RELEASE_ID INT  DEFAULT -1 NOT NULL,
		STATUS NVARCHAR(255),
		REQUIREMENT_TYPE NVARCHAR(255),
		REQUIREMENT_STATE NVARCHAR(255),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		DIFFICULTY NVARCHAR(255),
		STABILITY NVARCHAR(255),
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		CREATION_DATE DATETIME,
		PRIORITY NVARCHAR(255),
		CUSTOMER_PRIORITY NVARCHAR(255),
		PLATFORM NVARCHAR(255),
		REVISION_NUMBER NVARCHAR(50),
		REVISION_DATE DATETIME DEFAULT GETDATE() NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_REVISION_HISTORY (
		REQUIREMENT_REVISION_ID INT  NOT NULL,
		REQUIREMENT_ID INT  NOT NULL,
		REVISION_NUMBER NVARCHAR(50) DEFAULT '0' NOT NULL,
		RESOURCE_ID INT  DEFAULT -1 NOT NULL,
		CHANGE_DATE  DATETIME  DEFAULT GETDATE() NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


	
CREATE TABLE $(NF_SCHEMA).TESTSUITE (
		TESTSUITE_ID INT  NOT NULL,
	    TESTSUITE_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'TestSuite Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		CONFIGURATION_ID INT  DEFAULT -1 NOT NULL,
		ASSETREGISTRY_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		TESTSUITE_STATE NVARCHAR(255),
		LAST_UPDATED DATETIME,
		CREATION_DATE DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECUTION_RESULT (
		EXECUTION_RESULT_ID INT  DEFAULT -1 NOT NULL,
		EXECRES_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Execution Result Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		VERDICT NVARCHAR(255),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		BUILD_ID INT  DEFAULT -1 NOT NULL,
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		TESTTYPE_ID INT  DEFAULT -1 NOT NULL,
		TESTCASE_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		START_DATE DATETIME,
		END_DATE DATETIME,
		POINTS_BLOCKED INT  DEFAULT 0 NOT NULL,
		POINTS_INCONCLUSIVE INT  DEFAULT 0 NOT NULL,
		MACHINE NVARCHAR(255),
		POINTS_ATTEMPTED INT  DEFAULT 0 NOT NULL,
		POINTS_FAILED INT  DEFAULT 0 NOT NULL,
		POINTS_PASSED INT  DEFAULT 0 NOT NULL,
		POINTS_PERMFAILED INT  DEFAULT 0 NOT NULL,
		LAST_UPDATED DATETIME,
		CREATION_DATE DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CURRENCY (
		CURRENCY_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Currency Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		EXCHANGE_RATE DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		VALID_START_DATE DATETIME,
		VALID_FINISH_DATE DATETIME,
		DEFAULT_CURRENCY INT  DEFAULT 0 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).POOL (
		POOL_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Pool Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).RESOURCE (
		RESOURCE_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Resource Logon Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		FULL_NAME NVARCHAR(110) DEFAULT 'Resource Full Name Missing' NOT NULL,
		FIRST_NAME NVARCHAR(35),
		LAST_NAME NVARCHAR(35),
		MIDDLE_INITIAL NVARCHAR(35),
		RESOURCE_TYPE SMALLINT,
		STANDARD_RATE DECIMAL(18 , 2),
		OVERTIME_RATE DECIMAL(18 , 2),
		POOL_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TASK_CLASSIFICATION (
		TASK_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Task Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TASK_CATEGORY (
		TASK_CATEGORY_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Task Category Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		CATEGORY_TYPE NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PRODUCT (
		PRODUCT_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Product Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ASSETREGISTRY (
		ASSETREGISTRY_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'AssetRegistry Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ITERATION (
		ITERATION_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Iteration Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		ASSETREGISTRY_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		PHASE_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT-1 NOT NULL,
		STATUS NVARCHAR(255),
		START_DATE DATETIME,
		END_DATE DATETIME,
		EXPECTED_START_DATE DATETIME,
		EXPECTED_END_DATE DATETIME,
		EXPECTED_TOTAL_POINTS INT  DEFAULT 0 NOT NULL,
		EXPECTED_DEFECTS INT  DEFAULT 0 NOT NULL,
		EXPECTED_VALIDITY_RATE DECIMAL (18,2) DEFAULT 0.00 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).RELEASE (
		RELEASE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Release Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		PRODUCT_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		AVAILABILITY_DATE DATETIME ,
		DECOMISSION_DATE DATETIME ,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT (
		PROJECT_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Project Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_CLASS_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_MANAGER INT  DEFAULT -1 NOT NULL,
		PROJECT_CATEGORY_ID INT  DEFAULT -1 NOT NULL,
		START_DATE DATETIME,
		END_DATE DATETIME,
		SHIP_DATE DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TASK (
		TASK_ID INT  NOT NULL,
		TASK_CATEGORY_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Task Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		TASK_CLASS_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		TASK_STATE NVARCHAR(255),
		PRIORITY NVARCHAR(255),
		STATUS NVARCHAR(255),
		RESOLUTION NVARCHAR(255),
		TASK_TYPE NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_HIERARCHY (
		PARENT_PROJECT_ID INT  NOT NULL,
		CHILD_PROJECT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_DETAIL (
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		CURRENCY_ID INT  DEFAULT -1 NOT NULL,
		BASELINE_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BASELINE_START DATETIME ,
		BASELINE_FINISH DATETIME ,
		BASELINE_VARIANCE INT  DEFAULT 0 NOT NULL,
		BASELINE_ESTIMATED_COST DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BASELINE_ESTIMATED_START DATETIME ,
		BASELINE_ESTIMATED_FINISH DATETIME ,
		ACTUAL_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		CURRENT_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		PLANNED_BUDGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		ACTUAL_VARIANCE INT  DEFAULT 0,
		ACTUAL_START DATETIME ,
		ACTUAL_FINISH DATETIME ,
		PLANNED_START DATETIME ,
		PLANNED_FINISH DATETIME ,
		ACWP DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BAC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BCWP DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		BCWS DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EAC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EV_ETC DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		EV_FLAG DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL
		) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_TYPE (
		PROJECT_TYPE_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Project Type Name Missing' NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		RECORD_TYPE NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (
		PROJECT_WKCFG_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Work Configuartion Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		RECORD_TYPE NVARCHAR(255),
		PROJECT_TYPE_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_WORKCONFIG_HIERARCHY (
		PARENT_WKCFG_ID INT  NOT NULL,
		CHILD_WKCFG_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_CLASSIFICATION (
		PROJECT_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Project Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_CATEGORY (
		PROJECT_CATEGORY_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Project Category Name Missing' NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		CATEGORY_TYPE NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PHASE (
		PHASE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Project Phase Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		STATUS NVARCHAR(255),
		START_DATE DATETIME,
		END_DATE DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_ROLE (
		PROJECT_ROLE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Project Role Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_ROLE_MEMBER_LOOKUP (
		PROJECT_ROLE_ID INT  NOT NULL,
		RESOURCE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEAM (
		TEAM_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Team Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TASK_DETAIL (
		TASK_ID INT  DEFAULT -1 NOT NULL,
		PLANNED_START DATETIME ,
		PLANNED_FINISH DATETIME ,
		BASELINE_START DATETIME ,
		BASELINE_FINISH DATETIME ,
		ACTUAL_START DATETIME ,
		ACTUAL_FINISH DATETIME ,
		PLANNED_WORK INT  DEFAULT 0 NOT NULL,
		BASELINE_WORK INT ,
		REGULAR_WORK INT ,
		ACTUAL_WORK INT  DEFAULT 0 NOT NULL,
		REMAINING_WORK INT ,
		PLANNED_DURATION INT ,
		BASELINE_DURATION INT ,
		ACTUAL_DURATION INT ,
		REMAINING_DURATION INT ,
		START_VARIANCE INT ,
		FINISH_VARIANCE INT ,
		DURATION_VARIANCE INT ,
		PLANNED_OVT_WORK INT ,
		ACTUAL_OVT_WORK INT ,
		REMAINING_OVT_WORK INT ,
		PLANNED_COST DECIMAL(18 , 2),
		BASELINE_COST DECIMAL(18 , 2),
		ACTUAL_COST DECIMAL(18 , 2),
		REMAINING_COST DECIMAL(18 , 2),
		PLANNED_OVT_COST DECIMAL(18 , 2),
		ACTUAL_OVT_COST DECIMAL(18 , 2),
		REMAINING_OVT_COST DECIMAL(18 , 2),
		DEADLINE DATETIME ,
		EARLY_START DATETIME ,
		LATE_FINISH DATETIME ,
		EARLY_FINISH DATETIME ,
		LATE_START DATETIME ,
		CONSTRAINT_TYPE INT ,
		CONSTRAINT_DATE DATETIME ,
		PERCENT_COMPLETE DECIMAL(5 , 2),
		PERCENT_WORK_COMPLETE DECIMAL(5 , 2),
		ACWP DOUBLE PRECISION,
		BCWP DOUBLE PRECISION,
		BCWS DOUBLE PRECISION,
		EAC DOUBLE PRECISION,
		VAC DOUBLE PRECISION,
		WBS_CODE NVARCHAR(255)
		) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TASK_REQUIREMENT_LOOKUP (
		TASK_ID INT  NOT NULL,
		REQUIREMENT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CONFIGURATION (
		CONFIGURATION_ID INT  NOT NULL,
		CONFIGURATION_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Configuration Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT-1 NOT NULL,
		LAST_UPDATED DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE (
		CONFIGURATION_ATTRIBUTE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Configuration_Attribute Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE_LOOKUP (
		CONFIGURATION_ATTRIBUTE_ID INT  NOT NULL,
		CONFIGURATION_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITE_ITERATION_LOOKUP (
		TESTSUITE_ID INT  NOT NULL,
		ITERATION_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTPLAN (
		TESTPLAN_ID INT  NOT NULL,
		TESTPLAN_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'TestPlan Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		ASSETREGISTRY_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		LAST_UPDATED DATETIME,
		TESTPLAN_STATE NVARCHAR(255),
		CREATION_DATE DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTPLAN_ITERATION_LOOKUP (
		TESTPLAN_ID INT  NOT NULL,
		ITERATION_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTTYPE (
		TESTTYPE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'TestType Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTCASE (
		TESTCASE_ID INT  NOT NULL,
		TESTCASE_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'TestCase Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		TESTCASE_STATE NVARCHAR(255),
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		TESTPLAN_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT-1 NOT NULL,
		IS_BLOCKING INT  DEFAULT 0 NOT NULL,
		REGRESSION_TEST NVARCHAR(255),
		WEIGHT INT  DEFAULT 0,
		LAST_UPDATED DATETIME,
		TESTCASE_FOLDER NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTCASE_ITERATION_LOOKUP (
		TESTCASE_ID INT  NOT NULL,
		ITERATION_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_TESTCASE_LOOKUP (
		REQUIREMENT_ID INT  NOT NULL,
		TESTCASE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_TESTPLAN_LOOKUP (
		REQUIREMENT_ID INT  NOT NULL,
		TESTPLAN_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_TESTSUITE_LOOKUP (
		REQUIREMENT_ID INT  NOT NULL,
		TESTSUITE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_REQUIREMENT_LOOKUP (
		REQUIREMENT_ID INT  NOT NULL,
		CREQUIREMENT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_HIERARCHY (
		PRED_REQUIREMENT_ID INT  NOT NULL,
		SUCC_REQUIREMENT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECUTION_WORKITEM (
		EXECWORKITEM_ID INT  NOT NULL,
		EXECWORKIT_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Execution Work Item Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		CONFIGURATION_ID INT  DEFAULT -1 NOT NULL,
		EXECUTION_WORKITEM_STATE NVARCHAR(255),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		TESTCASE_ID INT  DEFAULT -1 NOT NULL,
		TESTTYPE_ID INT  DEFAULT -1 NOT NULL,
		TESTPLAN_ID INT  DEFAULT -1 NOT NULL,
		CURRENT_RESULT_ID INT  DEFAULT -1 NOT NULL,
		FREQUENCY NVARCHAR(255),
		REGRESSION NVARCHAR(255),
		WEIGHT INT  DEFAULT 0,
		TAGS NVARCHAR(255),
		LAST_UPDATED DATETIME,
		PRIORITY NVARCHAR(255),
		CREATION_DATE DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECWORKITEM_ITERATION_LOOKUP (
		EXECWORKITEM_ID INT  NOT NULL,
		ITERATION_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_EXECWRKITEM_LOOKUP (
		REQUIREMENT_ID INT  NOT NULL,
		EXECWORKITEM_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECWORKITEM_TESTSUITE_LOOKUP (
		EXECWORKITEM_ID INT  NOT NULL,
		TESTSUITE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST (
		REQUEST_ID INT  NOT NULL,
		REQUEST_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Request Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		BUILD_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_CATEGORY_ID INT  DEFAULT -1 NOT NULL,
		PHASE_ID INT  DEFAULT -1 NOT NULL,
		SEVERITY NVARCHAR(255),
		REQUEST_STATE NVARCHAR(255),
		PRIORITY NVARCHAR(255),
		PLATFORM NVARCHAR(255),
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		RELEASE_ID INT  DEFAULT -1 NOT NULL,
		FIXEDINRELEASE_ID INT  DEFAULT -1 NOT NULL,
		SLOC_CHANGE INT  DEFAULT 0,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		REQUEST_CATEGORY_ID INT  DEFAULT -1 NOT NULL,
		TEAM_ID INT  DEFAULT -1 NOT NULL,
		IS_BLOCKING INT  DEFAULT 0 NOT NULL,
		REQUEST_SOURCE NVARCHAR(255),
		CREATION_DATE DATETIME,
		CLOSED_DATE DATETIME,
		SUBMIT_DATE DATETIME,
		RESOLVED_DATE DATETIME,
		ASSIGNED_DATE DATETIME,
		DUPLICATE_DATE DATETIME,
		ACTIVATE_DATE DATETIME,
		STATUS NVARCHAR(255),
		CUSTOMER_PRIORITY NVARCHAR(255),
		RESOLUTION NVARCHAR(255),
		REQUEST_TYPE NVARCHAR(255),
		PLANNED_WORK INT ,
		ACTUAL_WORK INT ,
		COMMENT_COUNT INT ,                             
		SUBSCRIBER_COUNT INT ,
		STORY_POINTS INT ,                          
		TAGS NVARCHAR (255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_CLASSIFICATION (
		REQUEST_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Request Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_CLASSIFICATION (
		REQUIREMENT_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Requirement Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_STATE_HISTORY (
		REQUEST_STATE_HISTORY_ID INT  NOT NULL,
		REQUEST_ID INT  NOT NULL,
		PREV_REQUEST_STATE NVARCHAR(255),
		REQUEST_STATE NVARCHAR(255),
		CHANGE_DATE  DATETIME  DEFAULT GETDATE() NOT NULL,
		DAYS_IN_STATE INT  DEFAULT 0 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_HIERARCHY (
		PARENT_REQUEST_ID INT  NOT NULL,
		CHILD_REQUEST_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).FILE_VERSION (
		FILE_VERSION_ID INT  DEFAULT -1 NOT NULL,
		FILE_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'File Version Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		FILE_ID INT  DEFAULT -1 NOT NULL,
		CREATION_DATE DATETIME NOT NULL,
		NUM_SLOC INT  DEFAULT 0 NOT NULL,
		NUM_SLOC_CHANGED INT  DEFAULT 0 NOT NULL,
		AUTHOR_ID INT  DEFAULT -1 NOT NULL,
		ACTIVITY_ID INT  DEFAULT -1 NOT NULL,
		FILE_STREAM_ID INT  DEFAULT-1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		HASCOMMENT SMALLINT DEFAULT 0 NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).[FILE] (
		FILE_ID INT  NOT NULL,
		FILE_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'File Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		NUM_SLOC INT  DEFAULT 0 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).FILE_BASELINE (
		FILE_BASELINE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'File_Baseline Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).FILE_BASELINE_ACTIVITY_LOOKUP
		(FILE_BASELINE_ID INT  NOT NULL,
		ACTIVITY_ID INT  NOT NULL)
 ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).FILE_STREAM (
		FILE_STREAM_ID INT  NOT NULL,
		FILE_STREAM_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'File_Stream Name Missing' NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CONFIG_EXECUTIONRES_LOOKUP (
		CONFIGURATION_ID INT  NOT NULL,
		EXECUTION_RESULT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITELOG (
		TESTSUITELOG_ID INT  NOT NULL,
		TESTSUITELOG_CLASS_ID INT  DEFAULT -1 NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Test Suite Log Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		VERDICT NVARCHAR(255),
		TESTSUITE_ID INT  DEFAULT -1 NOT NULL,
		BUILD_ID INT  DEFAULT -1 NOT NULL,
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		START_DATE DATETIME,
		END_DATE DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITELOG_EXECRESULT_LOOKUP (
		TESTSUITELOG_ID INT  NOT NULL,
		EXECUTION_RESULT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TASK_REQUEST_LOOKUP (
		TASK_ID INT  NOT NULL,
		REQUEST_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_REQUEST_LOOKUP (
		REQUIREMENT_ID INT  NOT NULL,
		REQUEST_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_CUSTOMER_LOOKUP (
		REQUEST_ID INT  NOT NULL,
		CUSTOMER_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUIREMENT_CUSTOMER_LOOKUP (
		REQUIREMENT_ID INT  NOT NULL,
		CUSTOMER_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECRES_REQUEST_LOOKUP (
		REQUEST_ID INT  NOT NULL,
		EXECUTION_RESULT_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).RISK (
		RISK_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Risk Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		REQUIREMENT_ID INT  DEFAULT -1 NOT NULL,
		PRIORITY NVARCHAR(255),
		RISK_STATE NVARCHAR(255),
		OCCURED_DATETIME DATETIME,
		IMPACT_RANK NVARCHAR(255),
		PROBABILITY_RANK NVARCHAR(255),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		RELEASE_ID INT  DEFAULT -1 NOT NULL,
		ITERATION_ID INT  DEFAULT -1 NOT NULL,
		TARGET_DATE DATETIME,
		CREATION_DATE DATETIME,
		CLOSE_DATE DATETIME,
		IMPACT_CATEGORY NVARCHAR(255),
		CONSEQUENCE_COST DECIMAL(18,2),
		RISK_MANAGEMENT_ACTION NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).RISK_STATE_HISTORY (
		RISK_STATE_HISTORY_ID INT  NOT NULL,
		RISK_ID INT  NOT NULL,
		PREV_RISK_STATE NVARCHAR(255),
		RISK_STATE NVARCHAR(255),
		CHANGE_DATE  DATETIME  DEFAULT GETDATE() NOT NULL,
		DAYS_IN_STATE INT  DEFAULT 0 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).FACTOR (
		FACTOR_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Factor Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		RISK_ID INT  DEFAULT -1 NOT NULL,
		MITIGATION_COST DECIMAL(18 , 2),
		PRIORITY NVARCHAR(255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJECT_BASELINE (
		BASELINE_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Project_Baseline Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT -1 NOT NULL,
		FILE_STREAM_ID INT  DEFAULT -1 NOT NULL,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).PROJ_BASELINE_BASELINE_LOOKUP (
		BASELINE_ID INT  NOT NULL,
		COMPBASELINE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).COMMENT (
		COMMENT_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		RESPONSE_COMMENT_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		REQUEST_ID INT  DEFAULT -1 NOT NULL,
		TASK_ID INT  DEFAULT -1 NOT NULL,
		ACTIVITY_ID INT  DEFAULT -1 NOT NULL,
		CREATION_DATE DATETIME,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ACTIVITY_DETAIL (
		ACTIVITY_ID INT  DEFAULT -1 NOT NULL,
		PLANNED_START DATETIME ,
		PLANNED_FINISH DATETIME ,
		BASELINE_START DATETIME ,
		ACTUAL_START DATETIME ,
		BASELINE_FINISH DATETIME ,
		ACTUAL_FINISH DATETIME ,
		START_VARIANCE INT ,
		FINISH_VARIANCE INT ,
		PLANNED_WORK INT ,
		BASELINE_WORK INT ,
		REGULAR_WORK INT ,
		ACTUAL_WORK INT ,
		REMAINING_WORK INT ,
		PLANNED_COST DECIMAL(18 , 2),
		BASELINE_COST DECIMAL(18 , 2),
		ACTUAL_COST DECIMAL(18 , 2),
		REMAINING_COST DECIMAL(18 , 2),
		PLANNED_OVT_WORK DECIMAL(18 , 2),
		ACTUAL_OVT_WORK DECIMAL(18 , 2),
		REMAINING_OVT_WORK DECIMAL(18 , 2),
		ACTUAL_OVT_COST DECIMAL(18 , 2),
		REMAINING_OVT_COST DECIMAL(18 , 2),
		UNITS INT ,
		DELAY INT ,
		ACWP DOUBLE PRECISION,
		BCWP DOUBLE PRECISION,
		BCWS DOUBLE PRECISION,
		EAC DOUBLE PRECISION,
		RESOURCE_TYPE NCHAR(18),
		IS_OVERALLOCATED SMALLINT,
		IS_CONFIRMED SMALLINT
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECRES_EXECWKITEM_LOOKUP (
		EXECUTION_RESULT_ID INT  NOT NULL,
		EXECWORKITEM_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CONFIG_EXECUTIONWORKITM_LOOKUP (
		CONFIGURATION_ID INT  NOT NULL,
		EXECWORKITEM_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEST_CATEGORY (
		TEST_CATEGORY_ID INT  NOT NULL,
		NAME NVARCHAR (255) DEFAULT 'Test Category Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		TERM NVARCHAR (255),
		VALUE NVARCHAR (255),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTPLAN_CATEGORY_LOOKUP (
		TEST_CATEGORY_ID INT  NOT NULL,
		TESTPLAN_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTCASE_CATEGORY_LOOKUP (
		TEST_CATEGORY_ID INT  NOT NULL,
		TESTCASE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITE_TESTCASE_LOOKUP (
		TESTCASE_ID INT  NOT NULL,
		TESTSUITE_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITE_TESTSUITELOG_LOOKUP (
		TESTSUITE_ID INT  NOT NULL,
		TESTSUITELOG_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTPLAN_TESTPLAN_HIERARCHY (
		PARENT_TESTPLAN_ID INT  NOT NULL,
		CHILD_TESTPLAN_ID INT  NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTPLAN_TESTCASE_LOOKUP  (
		  TESTPLAN_ID INT  NOT NULL, 
		  TESTCASE_ID INT  NOT NULL)
ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).LAB_RESOURCE (
			LAB_RESOURCE_ID INT  NOT NULL,
			NAME NVARCHAR(255) DEFAULT 'Missing Lab Resource Name' NOT NULL,
			REFERENCE_ID NVARCHAR(50),
			EXTERNAL_ID NVARCHAR(100),
			LAB_RESOURCE_TYPE NVARCHAR(255),
			LAB_RESOURCE_NAME NVARCHAR(255),
			MEMORY INT ,
			IP_ADDRESS NVARCHAR(40),
			PRIMARY_MAC_ADDRESS NCHAR(18),
			ADMINISTRATIVE_STATUS NVARCHAR(255),
			OPERATIONAL_STATUS NVARCHAR(255),
			HOSTNAME NVARCHAR(255),
			FULLY_QUALIFIED_DOMAIN_NAME NVARCHAR(255),
			OS_TYPE NVARCHAR(255),
			OS_LOCALE NVARCHAR(255),
			OS_KERNEL_WIDTH NVARCHAR(255),
			CPU_SPEED INT ,
			CPU_ARCHITECTURE NVARCHAR(255),
			CPU_ARCHITECTURE_WIDTH NVARCHAR(255),
			CPU_MANUFACTURER NVARCHAR(255),
			CPU_TYPE NVARCHAR(255), 
			DISK_SPACE INT ,
			SOFTWARE NVARCHAR(255),
			RESOURCE_GROUP_ID INT  DEFAULT -1 NOT NULL,
			PROJECT_ID INT  DEFAULT -1 NOT NULL,
			URL NVARCHAR(2048),
			EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
			EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
			SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
			REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
			ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).RESOURCE_GROUP (
			RESOURCE_GROUP_ID INT  NOT NULL,
			NAME NVARCHAR(255) DEFAULT 'Missing Resource Group Name' NOT NULL,
			REFERENCE_ID NVARCHAR(50),
			EXTERNAL_ID NVARCHAR(100),
			PROJECT_ID INT  DEFAULT-1 NOT NULL,
			IS_EXPIREABLE NVARCHAR(255),
			START_DATE DATETIME,
			EXPIRATION_DATE DATETIME,
			URL NVARCHAR(2048),
			EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
			EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
			SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
			REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
			ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).RESERVATION (
			RESERVATION_ID INT  NOT NULL,
			NAME NVARCHAR(255) DEFAULT 'Missing Reservation Name' NOT NULL,
			REFERENCE_ID NVARCHAR(50),
			EXTERNAL_ID NVARCHAR(100),
			RESERVED_FOR NVARCHAR(255),
			RESERVED_BY NVARCHAR(255),
			RESERVE_TO DATETIME,
			RESERVE_FROM DATETIME,
			LAB_RESOURCE_ID INT  DEFAULT -1 NOT NULL,
			PROJECT_ID INT  DEFAULT-1 NOT NULL,
			URL NVARCHAR(2048),
			EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
			EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
			SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
			REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
			ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTCASE_CLASSIFICATION (
		TESTCASE_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Testcase Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTPLAN_CLASSIFICATION (
		TESTPLAN_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Testplan Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITE_CLASSIFICATION (
		TESTSUITE_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Testsuite Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TESTSUITELOG_CLASSIFICATION (
		TESTSUITELOG_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Testsuitelog Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECRESULT_CLASSIFICATION (
		EXECRES_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Execution Result Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).EXECWORKITEM_CLASSIFICATION (
		EXECWORKIT_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Execution Work Item Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).CONFIGURATION_CLASSIFICATION (
		CONFIGURATION_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'Configuration Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).ACTIVITY_STATE_HISTORY (
		ACTIVITY_STATE_HISTORY_ID INT  NOT NULL,
		ACTIVITY_ID INT  NOT NULL,
		PREV_ACTIVITY_STATE NVARCHAR(255),
		ACTIVITY_STATE NVARCHAR(255),
		CHANGE_DATE  DATETIME  DEFAULT GETDATE() NOT NULL,
		DAYS_IN_STATE INT  DEFAULT 0 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_CATEGORY (
		REQUEST_CATEGORY_ID INT  NOT NULL,
		NAME NVARCHAR(255) DEFAULT 'Request Category Name Missing' NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

	
CREATE TABLE $(NF_SCHEMA).FILE_CLASSIFICATION (
		FILE_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'File Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).FILE_STREAM_CLASSIFICATION (
		FILE_STREAM_CLASS_ID INT  NOT NULL,
		NAME NVARCHAR(50) DEFAULT 'File Stream Class Name Missing' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TASK_STATE_HISTORY (
		TASK_STATE_HISTORY_ID INT  NOT NULL,
		TASK_ID INT  NOT NULL,
		PREV_TASK_STATE NVARCHAR(255),
		TASK_STATE NVARCHAR(255),
		CHANGE_DATE  DATETIME  DEFAULT GETDATE() NOT NULL,
		DAYS_IN_STATE INT  DEFAULT 0 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY	(
		REQCHANGE_HISTORY_ID INT  NOT NULL,
		REQUEST_CLASS_ID INT  DEFAULT -1 NOT NULL,
		REQUEST_ID INT  DEFAULT -1 NOT NULL,                          
		PREV_TEAM_ID INT  DEFAULT -1 NOT NULL,                           
		PREV_REQUEST_CATEGORY_ID INT  DEFAULT -1 NOT NULL,                  
		PREV_ITERATION_ID INT  DEFAULT -1 NOT NULL,                                              
		PREV_OWNER_ID INT  DEFAULT -1 NOT NULL,  
		CHANGE_DATE DATETIME,                                    
		PREV_REQUEST_TYPE NVARCHAR (255),                        
		PREV_STATE NVARCHAR (255),                             
		PREV_PRIORITY NVARCHAR (255),                            
		PREV_SEVERITY NVARCHAR (255),                           
		PREV_COMMENT_COUNT INT ,                         
		PREV_SUBSCRIBER_COUNT INT ,                      
		PREV_TAGS NVARCHAR (255),                                 
		PREV_PLANNED_WORK INT ,                      
		PREV_ACTUAL_WORK INT ,                       
		PREV_STORY_POINTS INT ,                          
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


---RTC
CREATE TABLE $(NF_SCHEMA).BUILD_COMPILATION_RESULT	( 
		BUILD_COMPRES_ID INT  NOT NULL,                       
		BUILD_ID INT  DEFAULT -1 NOT NULL,               
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,          
		COMPILE_ERROR_COUNT INT ,   
		COMPILE_WARNING_COUNT INT ,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

	                        
CREATE TABLE $(NF_SCHEMA).BUILD_UNIT_RESULT	( 
        BUILD_UNITRES_ID INT  NOT NULL,	      
		BUILD_ID INT  DEFAULT -1 NOT NULL,              
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,           
		UNIT_TEST_COUNT INT ,        
		UNIT_FAILURE_COUNT INT ,    
		UNIT_ERROR_COUNT INT ,
		URL NVARCHAR(2048),
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).BUILD_UNIT_EVENT	(                    
		BUILD_UNIT_EVENT_ID INT  NOT NULL,	      
		BUILD_ID INT  DEFAULT -1 NOT NULL,                 
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,                           
		UNIT_EVENT NVARCHAR(255),           
		UNIT_TEST NVARCHAR(255),   
		URL NVARCHAR(2048),          
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO

   
CREATE TABLE $(NF_SCHEMA).UNIT_TEST_RESULT (	
		UNIT_TEST_RESULT_ID INT  NOT NULL,              
		PROJECT_ID INT  DEFAULT -1 NOT NULL,               
		TEAM_ID INT  DEFAULT -1 NOT NULL,                 
		BUILD_TYPE NVARCHAR(255),         
		COMPONENT_ID INT  DEFAULT -1 NOT NULL,            
		UNIT_EVENT NVARCHAR(255),        
		UNIT_TEST NVARCHAR(255),           
		UNIT_COUNT INT , 
		URL NVARCHAR(2048),           
		LAST_RUN_DATE DATETIME,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR (36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).JOB (
		JOB_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Job Name Missing' NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		PROJECT_ID INT  DEFAULT-1 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO




CREATE TABLE $(NF_SCHEMA).JOB_RESULT(
		JOB_RESULT_ID INT  NOT NULL,
		REFERENCE_ID NVARCHAR(50),
		EXTERNAL_ID NVARCHAR(100),
		NAME NVARCHAR(255) DEFAULT 'Job Result Name Missing' NOT NULL,
		STATE NVARCHAR(255),
		VERDICT NVARCHAR(255), 
		START_TIME DATETIME,
		END_TIME DATETIME,
		DURATION INT ,
		LAB_RESOURCE_ID INT  DEFAULT -1 NOT NULL,
		OWNER_ID INT  DEFAULT -1 NOT NULL,
		JOB_ID INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		URL NVARCHAR(2048),
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).M_PROJECT (
		MAP_KEY1 INT ,
		MAP_KEY2 NVARCHAR(255),
		TARGET_PROJECT_ID INT  NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).M_PRODUCT (
		MAP_KEY1 INT ,
		MAP_KEY2 NVARCHAR(255),
		TARGET_PRODUCT_ID INT  NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).M_COMPONENT (
		MAP_KEY1 INT ,
		MAP_KEY2 NVARCHAR(255),
		TARGET_COMPONENT_ID INT  NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).M_ITERATION (
		MAP_KEY1 INT ,
		MAP_KEY2 NVARCHAR(255),
		TARGET_ITERATION_ID INT  NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).M_RELEASE (
		MAP_KEY1 INT ,
		MAP_KEY2 NVARCHAR(255),
		TARGET_RELEASE_ID INT  NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).M_RESOURCE (
		MAP_KEY1 INT ,
		MAP_KEY2 NVARCHAR(255),
		TARGET_RESOURCE_ID INT  NOT NULL,
		EXTERNAL_KEY1 INT  DEFAULT -1 NOT NULL,
		EXTERNAL_KEY2 NCHAR(40) DEFAULT '-1' NOT NULL,
		SOURCE_ID NVARCHAR(36) DEFAULT '-1' NOT NULL,
		REC_DATETIME DATETIME DEFAULT GETDATE() NOT NULL,
		ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL
) ON VNF_32K 
GO


----


CREATE TABLE $(NF_SCHEMA).TEMP_ITERATION  (
		  NAME NVARCHAR(256) , 
		  SOURCE_ID NVARCHAR(36) )   
 ON VNF_32K 
GO

 

CREATE TABLE $(NF_SCHEMA).TEMP_BUILD  (
		  NAME NVARCHAR(256) , 
		  SOURCE_ID NVARCHAR(36) )   
 ON VNF_32K 
GO

 

CREATE TABLE $(NF_SCHEMA).TEMP_RELEASE  (
		  NAME NVARCHAR(256) , 
		  SOURCE_ID NVARCHAR(36) )   
 ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_PROJECT
(		PROJECTUNIQUEID NVARCHAR(256),
		PROJECTNAME NVARCHAR(256),
		PROJECTDATECREATED DATETIME,
		PROJECTHREF NVARCHAR(2048),
		COMPONENTUNIQUEID NVARCHAR(256),
		STREAMUNIQUEID NVARCHAR(256),
		STREAMNAME NVARCHAR(256),
		STREAMHREF NVARCHAR(2048),
		ACTIVITYUNIQUEID NVARCHAR(256),
		ACTIVITYNAME NVARCHAR(256),
		ACTIVITYOWNER NVARCHAR(256),
		ACTIVITYSTATE NVARCHAR(256),
		ACTIVITYDATECREATED DATETIME,
		ACTIVITYHREF NVARCHAR(2048),
		VERSIONUNIQUEID NVARCHAR(256),
		DATASOURCE_ID NVARCHAR(36)
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_REQUEST_HISTORY
	(
	HISTORY_DBID INT ,
	HISTORY_UUID_DBID NVARCHAR(256),
	HISTORY_ACTION_TIMESTAMP DATETIME,
	DATASOURCE_ID NVARCHAR(36),
	HISTORY_OLD_STATE NVARCHAR(256),
	HISTORY_NEW_STATE NVARCHAR(256),
	DBID INT ,
	DBID_UUID NVARCHAR(256)
	) ON VNF_32K 
GO

	
CREATE TABLE $(NF_SCHEMA).TEMP_TEST_CATEGORY
	(
	CATEGORY_VALUE NVARCHAR(255),
	CATEGORY_TERM NVARCHAR(255),
	DATASOURCE_ID NVARCHAR(36)
	) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_ACTIVITY_HISTORY
	(
	HISTORY_DBID INT ,
	HISTORY_ACTION_TIMESTAMP DATETIME,
	DATASOURCE_ID NVARCHAR(36),
	HISTORY_OLD_STATE NVARCHAR(256),
	HISTORY_NEW_STATE NVARCHAR(256),
	DBID INT 
	) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_TASK_HISTORY
	(
	HISTORY_DBID INT ,
	HISTORY_ACTION_TIMESTAMP DATETIME,
	DATASOURCE_ID NVARCHAR(36),
	HISTORY_OLD_STATE NVARCHAR(256),
	HISTORY_NEW_STATE NVARCHAR(256),
	DBID INT 
	) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_FILEVERSION 
(		CREATEDBY NVARCHAR(256),
		DATECREATED DATETIME,
		VERSIONNUMBER NVARCHAR(256),
		LINESOFCODE INT ,
		BRANCH  NVARCHAR(256),
		UNIQUEID  NVARCHAR(256),
		CHANGESFROMPREDECESSOR INT ,
		FILEELEMENTUNIQUEID NVARCHAR(256),
		FILEELEMENTNAME NVARCHAR(256),
		DATASOURCE_ID NVARCHAR(36)
) ON VNF_32K 
GO


CREATE TABLE $(NF_SCHEMA).TEMP_COMPONENT
(		COMPONENTNAME NVARCHAR(256),
		COMPONENTUNIQUEID NVARCHAR(256),
		COMPONENTHREF NVARCHAR(2048),
		FILEELEMENTUNIQUEID NVARCHAR(256),
		BASELINENAME NVARCHAR(256),
		BASELINEUNIQUEID NVARCHAR(256),
		BASELINEHREF NVARCHAR(2048),
		BASELINEACTIVITIESUNIQUEID NVARCHAR(256),
		DATASOURCE_ID NVARCHAR(36)
) ON VNF_32K 
GO




-- INDEXES

CREATE INDEX ACTI_IDX1 ON $(NF_SCHEMA).ACTIVITY (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX ASETR_IDX1 ON $(NF_SCHEMA).ASSETREGISTRY (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX BUILD_IDX1 ON $(NF_SCHEMA).BUILD (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX COMMENT_IDX1 ON $(NF_SCHEMA).COMMENT (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX COMPONENT_IDX1 ON $(NF_SCHEMA).COMPONENT (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX COMPTEAM_IDX1 ON $(NF_SCHEMA).TEAM (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX CONFIG_IDX1 ON $(NF_SCHEMA).CONFIGURATION (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX CONFIGATT_IDX1 ON $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX EXECWKI_TSTC_IDX1 ON $(NF_SCHEMA).EXECUTION_WORKITEM (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX CURRENCY_IDX1 ON $(NF_SCHEMA).CURRENCY (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX CUSTOMER_IDX1 ON $(NF_SCHEMA).CUSTOMER (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX FACTOR_IDX1 ON $(NF_SCHEMA).FACTOR (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX FILE_IDX1 ON $(NF_SCHEMA).[FILE] (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX FILESTR_IDX1 ON $(NF_SCHEMA).FILE_STREAM (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX FILEVER_IDX1 ON $(NF_SCHEMA).FILE_VERSION (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX ITERATION_IDX1 ON $(NF_SCHEMA).ITERATION (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX POOL_IDX1 ON $(NF_SCHEMA).POOL (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PRODUCT_IDX1 ON $(NF_SCHEMA).PRODUCT (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROJECT_IDX1 ON $(NF_SCHEMA).PROJECT (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROJBASE_IDX1 ON $(NF_SCHEMA).PROJECT_BASELINE (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROJCAT_IDX1 ON $(NF_SCHEMA).PROJECT_CATEGORY (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PHASE_IDX1 ON $(NF_SCHEMA).PHASE (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROJROLE_IDX1 ON $(NF_SCHEMA).PROJECT_ROLE (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROJTYPE_IDX1 ON $(NF_SCHEMA).PROJECT_TYPE (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX PROJWRKCFG_IDX1 ON $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX RELEASE_IDX1 ON $(NF_SCHEMA).RELEASE (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX1 ON $(NF_SCHEMA).REQUEST (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQSTH_IDX1 ON $(NF_SCHEMA).REQUEST_STATE_HISTORY (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQUI_IDX1 ON $(NF_SCHEMA).REQUIREMENT (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX RESOURCE_IDX1 ON $(NF_SCHEMA).RESOURCE (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX RISK_IDX1 ON $(NF_SCHEMA).RISK (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX RISKSTH_IDX1 ON $(NF_SCHEMA).RISK_STATE_HISTORY (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TESTSUITELOG_IDX1 ON $(NF_SCHEMA).TESTSUITELOG (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TASK_IDX1 ON $(NF_SCHEMA).TASK (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TASKCAT_IDX1 ON $(NF_SCHEMA).TASK_CATEGORY (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TESTCASE_IDX1 ON $(NF_SCHEMA).TESTCASE (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX EXECRES_IDX1 ON $(NF_SCHEMA).EXECUTION_RESULT (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TESTPLAN_IDX1 ON $(NF_SCHEMA).TESTPLAN (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TESTSUITE_IDX1 ON $(NF_SCHEMA).TESTSUITE (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TESTTYPE_IDX1 ON $(NF_SCHEMA).TESTTYPE (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX LABRES_IDX1 ON $(NF_SCHEMA).LAB_RESOURCE (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX RESGRP_IDX1 ON $(NF_SCHEMA).RESOURCE_GROUP (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX RESERV_IDX1 ON $(NF_SCHEMA).RESERVATION (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX ACTSTH_IDX1 ON $(NF_SCHEMA).ACTIVITY_STATE_HISTORY (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX TSKSTH_IDX1 ON $(NF_SCHEMA).TASK_STATE_HISTORY (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX JOB_IDX1 ON $(NF_SCHEMA).JOB (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX JOBRES_IDX1 ON $(NF_SCHEMA).JOB_RESULT (SOURCE_ID,ISSOFTDELETED)  ON VNF_IDX
GO

CREATE INDEX ACTI_IDX2 ON $(NF_SCHEMA).ACTIVITY (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX ASETR_IDX2 ON $(NF_SCHEMA).ASSETREGISTRY (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX BUILD_IDX2 ON $(NF_SCHEMA).BUILD (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX COMMENT_IDX2 ON $(NF_SCHEMA).COMMENT (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX COMPONENT_IDX2 ON $(NF_SCHEMA).COMPONENT (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX COMPTEAM_IDX2 ON $(NF_SCHEMA).TEAM (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX CONFIG_IDX2 ON $(NF_SCHEMA).CONFIGURATION (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX CONFIGATT_IDX2 ON $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX EXECWKI_TSTC_IDX2 ON $(NF_SCHEMA).EXECUTION_WORKITEM (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX CURRENCY_IDX2 ON $(NF_SCHEMA).CURRENCY (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX CUSTOMER_IDX2 ON $(NF_SCHEMA).CUSTOMER (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX FACTOR_IDX2 ON $(NF_SCHEMA).FACTOR (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX FILE_IDX2 ON $(NF_SCHEMA).[FILE] (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX FILESTR_IDX2 ON $(NF_SCHEMA).FILE_STREAM (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX FILEVER_IDX2 ON $(NF_SCHEMA).FILE_VERSION (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX ITERATION_IDX2 ON $(NF_SCHEMA).ITERATION (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX POOL_IDX2 ON $(NF_SCHEMA).POOL (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX PRODUCT_IDX2 ON $(NF_SCHEMA).PRODUCT (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX PROJECT_IDX2 ON $(NF_SCHEMA).PROJECT (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX PROJBASE_IDX2 ON $(NF_SCHEMA).PROJECT_BASELINE (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX PROJCAT_IDX2 ON $(NF_SCHEMA).PROJECT_CATEGORY (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX PHASE_IDX2 ON $(NF_SCHEMA).PHASE (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX PROJROLE_IDX2 ON $(NF_SCHEMA).PROJECT_ROLE (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX PROJTYPE_IDX2 ON $(NF_SCHEMA).PROJECT_TYPE (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX PROJWRKCFG_IDX2 ON $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX RELEASE_IDX2 ON $(NF_SCHEMA).RELEASE (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX2 ON $(NF_SCHEMA).REQUEST (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX REQSTH_IDX2 ON $(NF_SCHEMA).REQUEST_STATE_HISTORY (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX REQUI_IDX2 ON $(NF_SCHEMA).REQUIREMENT (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX RESOURCE_IDX2 ON $(NF_SCHEMA).RESOURCE (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX RISK_IDX2 ON $(NF_SCHEMA).RISK (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX RISKSTH_IDX2 ON $(NF_SCHEMA).RISK_STATE_HISTORY (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX TESTSUITELOG_IDX2 ON $(NF_SCHEMA).TESTSUITELOG (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX TASK_IDX2 ON $(NF_SCHEMA).TASK (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX TASKCAT_IDX2 ON $(NF_SCHEMA).TASK_CATEGORY (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX TESTCASE_IDX2 ON $(NF_SCHEMA).TESTCASE (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX EXECRES_IDX2 ON $(NF_SCHEMA).EXECUTION_RESULT (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX TESTPLAN_IDX2 ON $(NF_SCHEMA).TESTPLAN (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX TESTSUITE_IDX2 ON $(NF_SCHEMA).TESTSUITE (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX TESTTYPE_IDX2 ON $(NF_SCHEMA).TESTTYPE (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX LABRES_IDX2 ON $(NF_SCHEMA).LAB_RESOURCE (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX RESGRP_IDX2 ON $(NF_SCHEMA).RESOURCE_GROUP (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX RESERV_IDX2 ON $(NF_SCHEMA).RESERVATION (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX ACTSTH_IDX2 ON $(NF_SCHEMA).ACTIVITY_STATE_HISTORY (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX TSKSTH_IDX2 ON $(NF_SCHEMA).TASK_STATE_HISTORY (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX JOB_IDX2 ON $(NF_SCHEMA).JOB (EXTERNAL_KEY1)  ON VNF_IDX
GO
CREATE INDEX JOBRES_IDX2 ON $(NF_SCHEMA).JOB_RESULT (EXTERNAL_KEY1)  ON VNF_IDX
GO

CREATE INDEX ACTI_IDX3 ON $(NF_SCHEMA).ACTIVITY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX ASETR_IDX3 ON $(NF_SCHEMA).ASSETREGISTRY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX BUILD_IDX3 ON $(NF_SCHEMA).BUILD (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX COMMENT_IDX3 ON $(NF_SCHEMA).COMMENT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX COMPONENT_IDX3 ON $(NF_SCHEMA).COMPONENT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX COMPTEAM_IDX3 ON $(NF_SCHEMA).TEAM (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX CONFIG_IDX3 ON $(NF_SCHEMA).CONFIGURATION (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX CONFIGATT_IDX3 ON $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX EXECWKI_TSTC_IDX3 ON $(NF_SCHEMA).EXECUTION_WORKITEM (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX CURRENCY_IDX3 ON $(NF_SCHEMA).CURRENCY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX CUSTOMER_IDX3 ON $(NF_SCHEMA).CUSTOMER (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX FACTOR_IDX3 ON $(NF_SCHEMA).FACTOR (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX FILE_IDX3 ON $(NF_SCHEMA).[FILE] (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX FILESTR_IDX3 ON $(NF_SCHEMA).FILE_STREAM (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX FILEVER_IDX3 ON $(NF_SCHEMA).FILE_VERSION (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX ITERATION_IDX3 ON $(NF_SCHEMA).ITERATION (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX POOL_IDX3 ON $(NF_SCHEMA).POOL (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PRODUCT_IDX3 ON $(NF_SCHEMA).PRODUCT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PROJECT_IDX3 ON $(NF_SCHEMA).PROJECT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PROJBASE_IDX3 ON $(NF_SCHEMA).PROJECT_BASELINE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PROJCAT_IDX3 ON $(NF_SCHEMA).PROJECT_CATEGORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PHASE_IDX3 ON $(NF_SCHEMA).PHASE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PROJROLE_IDX3 ON $(NF_SCHEMA).PROJECT_ROLE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PROJTYPE_IDX3 ON $(NF_SCHEMA).PROJECT_TYPE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX PROJWRKCFG_IDX3 ON $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX RELEASE_IDX3 ON $(NF_SCHEMA).RELEASE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX3 ON $(NF_SCHEMA).REQUEST (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX REQSTH_IDX3 ON $(NF_SCHEMA).REQUEST_STATE_HISTORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX REQUI_IDX3 ON $(NF_SCHEMA).REQUIREMENT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX RESOURCE_IDX3 ON $(NF_SCHEMA).RESOURCE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX RISK_IDX3 ON $(NF_SCHEMA).RISK (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX RISKSTH_IDX3 ON $(NF_SCHEMA).RISK_STATE_HISTORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TESTSUITELOG_IDX3 ON $(NF_SCHEMA).TESTSUITELOG (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TASK_IDX3 ON $(NF_SCHEMA).TASK (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TASKCAT_IDX3 ON $(NF_SCHEMA).TASK_CATEGORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TESTCASE_IDX3 ON $(NF_SCHEMA).TESTCASE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX EXECRES_IDX3 ON $(NF_SCHEMA).EXECUTION_RESULT (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TESTPLAN_IDX3 ON $(NF_SCHEMA).TESTPLAN (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TESTSUITE_IDX3 ON $(NF_SCHEMA).TESTSUITE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TESTTYPE_IDX3 ON $(NF_SCHEMA).TESTTYPE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX LABRES_IDX3 ON $(NF_SCHEMA).LAB_RESOURCE (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX RESGRP_IDX3 ON $(NF_SCHEMA).RESOURCE_GROUP (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX RESERV_IDX3 ON $(NF_SCHEMA).RESERVATION (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX ACTSTH_IDX3 ON $(NF_SCHEMA).ACTIVITY_STATE_HISTORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX TSKSTH_IDX3 ON $(NF_SCHEMA).TASK_STATE_HISTORY (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX JOB_IDX3 ON $(NF_SCHEMA).JOB (EXTERNAL_KEY2)  ON VNF_IDX
GO
CREATE INDEX JOBRES_IDX3 ON $(NF_SCHEMA).JOB_RESULT (EXTERNAL_KEY2)  ON VNF_IDX
GO

 
CREATE INDEX ACTI_IDX4 ON $(NF_SCHEMA).ACTIVITY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ASETR_IDX4 ON $(NF_SCHEMA).ASSETREGISTRY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX BUILD_IDX4 ON $(NF_SCHEMA).BUILD (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX COMMENT_IDX4 ON $(NF_SCHEMA).COMMENT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX COMPONENT_IDX4 ON $(NF_SCHEMA).COMPONENT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX COMPTEAM_IDX4 ON $(NF_SCHEMA).TEAM (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CONFIG_IDX4 ON $(NF_SCHEMA).CONFIGURATION (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CONFIGATT_IDX4 ON $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX EXECWKI_TSTC_IDX4 ON $(NF_SCHEMA).EXECUTION_WORKITEM (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CURRENCY_IDX4 ON $(NF_SCHEMA).CURRENCY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CUSTOMER_IDX4 ON $(NF_SCHEMA).CUSTOMER (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FACTOR_IDX4 ON $(NF_SCHEMA).FACTOR (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FILE_IDX4 ON $(NF_SCHEMA).[FILE] (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FILESTR_IDX4 ON $(NF_SCHEMA).FILE_STREAM (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FILEVER_IDX4 ON $(NF_SCHEMA).FILE_VERSION (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ITERATION_IDX4 ON $(NF_SCHEMA).ITERATION (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX POOL_IDX4 ON $(NF_SCHEMA).POOL (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PRODUCT_IDX4 ON $(NF_SCHEMA).PRODUCT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJECT_IDX4 ON $(NF_SCHEMA).PROJECT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJBASE_IDX4 ON $(NF_SCHEMA).PROJECT_BASELINE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJCAT_IDX4 ON $(NF_SCHEMA).PROJECT_CATEGORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PHASE_IDX4 ON $(NF_SCHEMA).PHASE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJROLE_IDX4 ON $(NF_SCHEMA).PROJECT_ROLE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJTYPE_IDX4 ON $(NF_SCHEMA).PROJECT_TYPE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJWRKCFG_IDX4 ON $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RELEASE_IDX4 ON $(NF_SCHEMA).RELEASE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX4 ON $(NF_SCHEMA).REQUEST (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQSTH_IDX4 ON $(NF_SCHEMA).REQUEST_STATE_HISTORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQUI_IDX4 ON $(NF_SCHEMA).REQUIREMENT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RESOURCE_IDX4 ON $(NF_SCHEMA).RESOURCE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RISK_IDX4 ON $(NF_SCHEMA).RISK (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RISKSTH_IDX4 ON $(NF_SCHEMA).RISK_STATE_HISTORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTSUITELOG_IDX4 ON $(NF_SCHEMA).TESTSUITELOG (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TASK_IDX4 ON $(NF_SCHEMA).TASK (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TASKCAT_IDX4 ON $(NF_SCHEMA).TASK_CATEGORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTCASE_IDX4 ON $(NF_SCHEMA).TESTCASE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX EXECRES_IDX4 ON $(NF_SCHEMA).EXECUTION_RESULT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTPLAN_IDX4 ON $(NF_SCHEMA).TESTPLAN (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTSUITE_IDX4 ON $(NF_SCHEMA).TESTSUITE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTTYPE_IDX4 ON $(NF_SCHEMA).TESTTYPE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX LABRES_IDX4 ON $(NF_SCHEMA).LAB_RESOURCE (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RESGRP_IDX4 ON $(NF_SCHEMA).RESOURCE_GROUP (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RESERV_IDX4 ON $(NF_SCHEMA).RESERVATION (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ACTSTH_IDX4 ON $(NF_SCHEMA).ACTIVITY_STATE_HISTORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TSKSTH_IDX4 ON $(NF_SCHEMA).TASK_STATE_HISTORY (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX JOB_IDX4 ON $(NF_SCHEMA).JOB (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX JOBRES_IDX4 ON $(NF_SCHEMA).JOB_RESULT (EXTERNAL_KEY1,SOURCE_ID)  ON VNF_IDX
GO


CREATE INDEX ACTI_IDX5 ON $(NF_SCHEMA).ACTIVITY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ASETR_IDX5 ON $(NF_SCHEMA).ASSETREGISTRY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX BUILD_IDX5 ON $(NF_SCHEMA).BUILD (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX COMMENT_IDX5 ON $(NF_SCHEMA).COMMENT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX COMPONENT_IDX5 ON $(NF_SCHEMA).COMPONENT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX COMPTEAM_IDX5 ON $(NF_SCHEMA).TEAM (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CONFIG_IDX5 ON $(NF_SCHEMA).CONFIGURATION (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CONFIGATT_IDX5 ON $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX EXECWKI_TSTC_IDX5 ON $(NF_SCHEMA).EXECUTION_WORKITEM (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CURRENCY_IDX5 ON $(NF_SCHEMA).CURRENCY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX CUSTOMER_IDX5 ON $(NF_SCHEMA).CUSTOMER (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FACTOR_IDX5 ON $(NF_SCHEMA).FACTOR (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FILE_IDX5 ON $(NF_SCHEMA).[FILE] (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FILESTR_IDX5 ON $(NF_SCHEMA).FILE_STREAM (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FILEVER_IDX5 ON $(NF_SCHEMA).FILE_VERSION (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ITERATION_IDX5 ON $(NF_SCHEMA).ITERATION (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX POOL_IDX5 ON $(NF_SCHEMA).POOL (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PRODUCT_IDX5 ON $(NF_SCHEMA).PRODUCT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJECT_IDX5 ON $(NF_SCHEMA).PROJECT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJBASE_IDX5 ON $(NF_SCHEMA).PROJECT_BASELINE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJCAT_IDX5 ON $(NF_SCHEMA).PROJECT_CATEGORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PHASE_IDX5 ON $(NF_SCHEMA).PHASE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJROLE_IDX5 ON $(NF_SCHEMA).PROJECT_ROLE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJTYPE_IDX5 ON $(NF_SCHEMA).PROJECT_TYPE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJWRKCFG_IDX5 ON $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RELEASE_IDX5 ON $(NF_SCHEMA).RELEASE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX5 ON $(NF_SCHEMA).REQUEST (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQSTH_IDX5 ON $(NF_SCHEMA).REQUEST_STATE_HISTORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQUI_IDX5 ON $(NF_SCHEMA).REQUIREMENT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RESOURCE_IDX5 ON $(NF_SCHEMA).RESOURCE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RISK_IDX5 ON $(NF_SCHEMA).RISK (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RISKSTH_IDX5 ON $(NF_SCHEMA).RISK_STATE_HISTORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTSUITELOG_IDX5 ON $(NF_SCHEMA).TESTSUITELOG (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TASK_IDX5 ON $(NF_SCHEMA).TASK (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TASKCAT_IDX5 ON $(NF_SCHEMA).TASK_CATEGORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTCASE_IDX5 ON $(NF_SCHEMA).TESTCASE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX EXECRES_IDX5 ON $(NF_SCHEMA).EXECUTION_RESULT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTPLAN_IDX5 ON $(NF_SCHEMA).TESTPLAN (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTSUITE_IDX5 ON $(NF_SCHEMA).TESTSUITE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TESTTYPE_IDX5 ON $(NF_SCHEMA).TESTTYPE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX LABRES_IDX5 ON $(NF_SCHEMA).LAB_RESOURCE (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RESGRP_IDX5 ON $(NF_SCHEMA).RESOURCE_GROUP (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX RESERV_IDX5 ON $(NF_SCHEMA).RESERVATION (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX ACTSTH_IDX5 ON $(NF_SCHEMA).ACTIVITY_STATE_HISTORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TSKSTH_IDX5 ON $(NF_SCHEMA).TASK_STATE_HISTORY (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX JOB_IDX5 ON $(NF_SCHEMA).JOB (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX JOBRES_IDX5 ON $(NF_SCHEMA).JOB_RESULT (EXTERNAL_KEY2,SOURCE_ID)  ON VNF_IDX
GO

CREATE INDEX REQUEST_IDX6 ON $(NF_SCHEMA).REQUEST (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX7 ON $(NF_SCHEMA).REQUEST (REQUEST_CLASS_ID ,REQUEST_ID ,EXTERNAL_KEY1 ,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX15 ON $(NF_SCHEMA).REQUEST (REQUEST_CLASS_ID ,REQUEST_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX8 ON $(NF_SCHEMA).REQUEST (REQUEST_ID ,EXTERNAL_KEY1 ,SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX9 ON $(NF_SCHEMA).REQUEST (BUILD_ID ,REQUEST_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX10 ON $(NF_SCHEMA).REQUEST (REQUEST_CLASS_ID ,PROJECT_ID ,COMPONENT_ID ,OWNER_ID ,REQUEST_ID ,ITERATION_ID)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX11 ON $(NF_SCHEMA).REQUEST (REQUEST_SOURCE)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX12 ON $(NF_SCHEMA).REQUEST (REQUEST_TYPE)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX13 ON $(NF_SCHEMA).REQUEST (STATUS)  ON VNF_IDX
GO
CREATE INDEX REQUEST_IDX14 ON $(NF_SCHEMA).REQUEST (COMPONENT_ID ,IS_BLOCKING ,REQUEST_ID)  ON VNF_IDX
GO
CREATE INDEX REQUI_IDX6 ON $(NF_SCHEMA).REQUIREMENT (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX REQUI_IDX7 ON $(NF_SCHEMA).REQUIREMENT (SOURCE_ID ,ISSOFTDELETED ,REQUIREMENT_ID )  ON VNF_IDX
GO
CREATE INDEX REQUI_IDX8 ON $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_CLASS_ID ,PROJECT_ID,COMPONENT_ID ,PLANNED_ITERATION_ID ,RELEASE_ID ,REQUIREMENT_ID ,OWNER_ID)  ON VNF_IDX
GO
CREATE INDEX FILEVER_IDX6 ON $(NF_SCHEMA).FILE_VERSION (FILE_ID ,FILE_VERSION_ID ,ACTIVITY_ID ,FILE_STREAM_ID)  ON VNF_IDX
GO
CREATE INDEX TASK_IDX6 ON $(NF_SCHEMA).TASK (ITERATION_ID)  ON VNF_IDX
GO
CREATE INDEX TASK_IDX7 ON $(NF_SCHEMA).TASK (TASK_TYPE)  ON VNF_IDX
GO
CREATE INDEX TMPHISREQ_IDX1 ON $(NF_SCHEMA).TEMP_REQUEST_HISTORY (DBID ,DATASOURCE_ID ,HISTORY_ACTION_TIMESTAMP)  ON VNF_IDX
GO
CREATE INDEX TMPHISREQ_IDX2 ON $(NF_SCHEMA).REQUEST_STATE_HISTORY (DAYS_IN_STATE ,REQUEST_ID)  ON VNF_IDX
GO
CREATE INDEX TMPHISREQ_IDX3 ON $(NF_SCHEMA).TEMP_REQUEST_HISTORY (HISTORY_OLD_STATE ,HISTORY_DBID ,HISTORY_NEW_STATE ,DBID ,DATASOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX FBASELNACT_IDX1 ON $(NF_SCHEMA).FILE_BASELINE_ACTIVITY_LOOKUP (ACTIVITY_ID)  ON VNF_IDX
GO
CREATE INDEX TMPHISREQ_IDX4 ON $(NF_SCHEMA).TEMP_REQUEST_HISTORY (HISTORY_NEW_STATE ,HISTORY_OLD_STATE ,DBID ,DATASOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX TMPHISREQ_IDX5 ON $(NF_SCHEMA).REQUEST_CHANGE_HISTORY (REQUEST_ID ,CHANGE_DATE)  ON VNF_IDX
GO
CREATE INDEX ACTI_IDX6 ON $(NF_SCHEMA).ACTIVITY (ISSOFTDELETED)  ON VNF_IDX
GO
CREATE INDEX ACTI_IDX7 ON $(NF_SCHEMA).ACTIVITY (OWNER_ID ,ACTIVITY_ID ,ACTIVITY_CLASS_ID ,TASK_ID)  ON VNF_IDX
GO
CREATE INDEX ACTI_IDX8 ON $(NF_SCHEMA).ACTIVITY (ACTIVITY_CLASS_ID ,OWNER_ID ,ACTIVITY_ID)  ON VNF_IDX
GO
CREATE INDEX ACTI_IDX9 ON $(NF_SCHEMA).ACTIVITY (SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX EXECWKI_IDX6 ON $(NF_SCHEMA).EXECUTION_WORKITEM (SOURCE_ID)  ON VNF_IDX
GO
CREATE INDEX PROJECT_IDX6 ON $(NF_SCHEMA).PROJECT (ISSOFTDELETED )  ON VNF_IDX
GO
CREATE INDEX BUILD_IDX6 ON $(NF_SCHEMA).BUILD (ISSOFTDELETED )  ON VNF_IDX
GO





ALTER TABLE $(NF_SCHEMA).CUSTOMER ADD CONSTRAINT CUSTOMER_PK PRIMARY KEY (CUSTOMER_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY_CLASSIFICATION ADD CONSTRAINT ACTIVITYCL_PK PRIMARY KEY (ACTIVITY_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_PK PRIMARY KEY (ACTIVITY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_ACTIVITY_LOOKUP ADD CONSTRAINT REQACT_PK PRIMARY KEY (REQUEST_ID,ACTIVITY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).COMPONENT ADD CONSTRAINT COMPONENT_PK PRIMARY KEY (COMPONENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_COMPONENT_LOOKUP ADD CONSTRAINT PRJCOMP_PK PRIMARY KEY (PROJECT_ID,COMPONENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).COMPONENT_CLASSIFICATION ADD CONSTRAINT COMPCLS_PK PRIMARY KEY (COMPONENT_CLASS_ID) ON  VNF_IDX
GO
	
ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_PK PRIMARY KEY (BUILD_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_PK PRIMARY KEY (REQUIREMENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REVISION_HISTORY ADD CONSTRAINT REQREV_PK PRIMARY KEY (REQUIREMENT_REVISION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE ADD CONSTRAINT TESTSUITE_PK PRIMARY KEY (TESTSUITE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_PK PRIMARY KEY (EXECUTION_RESULT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CURRENCY ADD CONSTRAINT CURRENCY_PK PRIMARY KEY (CURRENCY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).POOL ADD CONSTRAINT POOL_PK PRIMARY KEY (POOL_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE ADD CONSTRAINT RESOURCE_PK PRIMARY KEY (RESOURCE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_STATE_HISTORY ADD CONSTRAINT REQUESTSTATEHIS_PK PRIMARY KEY (REQUEST_STATE_HISTORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CLASSIFICATION ADD CONSTRAINT REQ_CATEGORY_PK PRIMARY KEY (REQUEST_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_CLASSIFICATION ADD CONSTRAINT REQUI_CATG_PK PRIMARY KEY (REQUIREMENT_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK_CATEGORY ADD CONSTRAINT TASK_CATEGORY_PK PRIMARY KEY (TASK_CATEGORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PRODUCT ADD CONSTRAINT PRODUCT_PK PRIMARY KEY (PRODUCT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ASSETREGISTRY ADD CONSTRAINT ASSETREGISTRY_PK PRIMARY KEY (ASSETREGISTRY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ITERATION ADD CONSTRAINT ITERATION_PK PRIMARY KEY (ITERATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RELEASE ADD CONSTRAINT RELEASE_PK PRIMARY KEY (RELEASE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_CLASSIFICATION ADD CONSTRAINT PROJECTCL_PK PRIMARY KEY (PROJECT_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT ADD CONSTRAINT PROJECT_PK PRIMARY KEY (PROJECT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK_CLASSIFICATION ADD CONSTRAINT TASKCL_PK PRIMARY KEY (TASK_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK ADD CONSTRAINT TASK_PK PRIMARY KEY (TASK_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_HIERARCHY ADD CONSTRAINT PROJECTHIER_PK PRIMARY KEY (PARENT_PROJECT_ID, CHILD_PROJECT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_DETAIL ADD CONSTRAINT PROJECTDT_PK PRIMARY KEY (PROJECT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_TYPE ADD CONSTRAINT PRJTYPE_PK PRIMARY KEY (PROJECT_TYPE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_WORKCONFIGURATION ADD CONSTRAINT PRJWKCFG_PK PRIMARY KEY (PROJECT_WKCFG_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_CATEGORY ADD CONSTRAINT PRJCAT_PK PRIMARY KEY (PROJECT_CATEGORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PHASE ADD CONSTRAINT PRJPHASE_PK PRIMARY KEY (PHASE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_ROLE ADD CONSTRAINT PRJROLE_PK PRIMARY KEY (PROJECT_ROLE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_ROLE_MEMBER_LOOKUP ADD CONSTRAINT PRJROLELK_PK PRIMARY KEY (PROJECT_ROLE_ID, RESOURCE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TEAM ADD CONSTRAINT CMPTEAM_PK PRIMARY KEY (TEAM_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK_DETAIL ADD CONSTRAINT TASKDT_PK PRIMARY KEY (TASK_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK_REQUIREMENT_LOOKUP ADD CONSTRAINT TSKREQ_PK PRIMARY KEY (TASK_ID, REQUIREMENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CONFIGURATION ADD CONSTRAINT CONFIGURATION_PK PRIMARY KEY (CONFIGURATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE ADD CONSTRAINT CFG_ATTRIBUTE_PK PRIMARY KEY (CONFIGURATION_ATTRIBUTE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE_LOOKUP ADD CONSTRAINT CFGATTR_ATTR_PK PRIMARY KEY (CONFIGURATION_ATTRIBUTE_ID, CONFIGURATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_ITERATION_LOOKUP ADD CONSTRAINT TSTITER_PK PRIMARY KEY (TESTSUITE_ID, ITERATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN ADD CONSTRAINT TESTPLAN_PK PRIMARY KEY (TESTPLAN_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_ITERATION_LOOKUP ADD CONSTRAINT TSPLNITER_PK PRIMARY KEY (TESTPLAN_ID, ITERATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTTYPE ADD CONSTRAINT TESTTYPE_PK PRIMARY KEY (TESTTYPE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE ADD CONSTRAINT TESTCASE_PK PRIMARY KEY (TESTCASE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_ITERATION_LOOKUP ADD CONSTRAINT TESTCITER_PK PRIMARY KEY (TESTCASE_ID, ITERATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTCASE_LOOKUP ADD CONSTRAINT REQTEST_PK PRIMARY KEY (REQUIREMENT_ID, TESTCASE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTPLAN_LOOKUP ADD CONSTRAINT REQTESTP_PK PRIMARY KEY (REQUIREMENT_ID, TESTPLAN_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTSUITE_LOOKUP ADD CONSTRAINT REQTESTS_PK PRIMARY KEY (REQUIREMENT_ID, TESTSUITE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REQUIREMENT_LOOKUP ADD CONSTRAINT REQTREQ_PK PRIMARY KEY (REQUIREMENT_ID, CREQUIREMENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_HIERARCHY ADD CONSTRAINT REQHIER_PK PRIMARY KEY (PRED_REQUIREMENT_ID, SUCC_REQUIREMENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_PK PRIMARY KEY (EXECWORKITEM_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_ITERATION_LOOKUP ADD CONSTRAINT EXWKIITER_PK PRIMARY KEY (EXECWORKITEM_ID, ITERATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_EXECWRKITEM_LOOKUP ADD CONSTRAINT REQEXWKI_PK PRIMARY KEY (REQUIREMENT_ID, EXECWORKITEM_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_TESTSUITE_LOOKUP ADD CONSTRAINT EXWKITSU_PK PRIMARY KEY (EXECWORKITEM_ID, TESTSUITE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_PK PRIMARY KEY (REQUEST_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_HIERARCHY ADD CONSTRAINT REQUHIST_PK PRIMARY KEY (PARENT_REQUEST_ID, CHILD_REQUEST_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).FILE_VERSION ADD CONSTRAINT FLVERSION_PK PRIMARY KEY (FILE_VERSION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).[FILE] ADD CONSTRAINT FILE_PK PRIMARY KEY (FILE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).FILE_BASELINE ADD CONSTRAINT FBASELINE_PK PRIMARY KEY (FILE_BASELINE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).FILE_BASELINE_ACTIVITY_LOOKUP ADD CONSTRAINT FBACT_PK PRIMARY KEY (FILE_BASELINE_ID,ACTIVITY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).FILE_STREAM ADD CONSTRAINT FSTREAM_PK PRIMARY KEY (FILE_STREAM_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CONFIG_EXECUTIONRES_LOOKUP ADD CONSTRAINT EXWKISLG_PK PRIMARY KEY (CONFIGURATION_ID, EXECUTION_RESULT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_PK PRIMARY KEY (TESTSUITELOG_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG_EXECRESULT_LOOKUP ADD CONSTRAINT STESEXECR_PK PRIMARY KEY (TESTSUITELOG_ID, EXECUTION_RESULT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK_REQUEST_LOOKUP ADD CONSTRAINT TSKISS_PK PRIMARY KEY (TASK_ID, REQUEST_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REQUEST_LOOKUP ADD CONSTRAINT REQIREQ_PK PRIMARY KEY (REQUIREMENT_ID, REQUEST_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CUSTOMER_LOOKUP ADD CONSTRAINT REQUCULK_PK PRIMARY KEY (REQUEST_ID, CUSTOMER_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_CUSTOMER_LOOKUP ADD CONSTRAINT REQUICLK_PK PRIMARY KEY (REQUIREMENT_ID, CUSTOMER_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECRES_REQUEST_LOOKUP ADD CONSTRAINT EXECRGREQ_PK PRIMARY KEY (REQUEST_ID, EXECUTION_RESULT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RISK ADD CONSTRAINT RISK_PK PRIMARY KEY (RISK_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RISK_STATE_HISTORY ADD CONSTRAINT RISKSTATEHIS_PK PRIMARY KEY (RISK_STATE_HISTORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).FACTOR ADD CONSTRAINT FACTOR_PK PRIMARY KEY (FACTOR_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_BASELINE ADD CONSTRAINT PRJBASELINE_PK PRIMARY KEY (BASELINE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJ_BASELINE_BASELINE_LOOKUP ADD CONSTRAINT PRJBSLTOBSL_PK PRIMARY KEY (BASELINE_ID, COMPBASELINE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).COMMENT ADD CONSTRAINT COMMENT_PK PRIMARY KEY (COMMENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY_DETAIL ADD CONSTRAINT ACTIVITY_DETAIL_PK PRIMARY KEY (ACTIVITY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_WORKCONFIG_HIERARCHY ADD CONSTRAINT PRJWCFGH_PK PRIMARY KEY(PARENT_WKCFG_ID,CHILD_WKCFG_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TEST_CATEGORY ADD CONSTRAINT TSTCAT_PK PRIMARY KEY (TEST_CATEGORY_ID) 	ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECRES_EXECWKITEM_LOOKUP ADD CONSTRAINT EXECRESWK_PK PRIMARY KEY (EXECUTION_RESULT_ID,EXECWORKITEM_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CONFIG_EXECUTIONWORKITM_LOOKUP  ADD CONSTRAINT CFGEXECWK_PK PRIMARY KEY (CONFIGURATION_ID,EXECWORKITEM_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_CATEGORY_LOOKUP ADD CONSTRAINT TPLNCAT_PK PRIMARY KEY (TEST_CATEGORY_ID,TESTPLAN_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_CATEGORY_LOOKUP ADD CONSTRAINT TCASECAT_PK PRIMARY KEY (TEST_CATEGORY_ID,TESTCASE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTCASE_LOOKUP ADD CONSTRAINT TSUTCASE_PK PRIMARY KEY (TESTCASE_ID,TESTSUITE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTSUITELOG_LOOKUP ADD CONSTRAINT TSUTSULG_PK PRIMARY KEY (TESTSUITE_ID,TESTSUITELOG_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_TESTPLAN_HIERARCHY ADD CONSTRAINT TPLNPC_PK PRIMARY KEY (PARENT_TESTPLAN_ID,CHILD_TESTPLAN_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_TESTCASE_LOOKUP ADD CONSTRAINT TPLNTC_PK PRIMARY KEY (TESTPLAN_ID,TESTCASE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).LAB_RESOURCE ADD CONSTRAINT LABRES_PK PRIMARY KEY (LAB_RESOURCE_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE_GROUP ADD CONSTRAINT RESGRP_PK PRIMARY KEY (RESOURCE_GROUP_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).RESERVATION ADD CONSTRAINT RESERV_PK PRIMARY KEY (RESERVATION_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_CLASSIFICATION ADD CONSTRAINT TCCLASS_PK PRIMARY KEY (TESTCASE_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_CLASSIFICATION ADD CONSTRAINT TPLCLASS_PK PRIMARY KEY (TESTPLAN_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_CLASSIFICATION ADD CONSTRAINT TSUCLASS_PK PRIMARY KEY (TESTSUITE_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG_CLASSIFICATION ADD CONSTRAINT  TSLCLASS_PK PRIMARY KEY (TESTSUITELOG_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECRESULT_CLASSIFICATION ADD CONSTRAINT EXRESCLASS_PK PRIMARY KEY (EXECRES_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_CLASSIFICATION ADD CONSTRAINT EXEWKITCLASS_PK PRIMARY KEY (EXECWORKIT_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).CONFIGURATION_CLASSIFICATION ADD CONSTRAINT CONFIGCLASS_PK PRIMARY KEY (CONFIGURATION_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY_STATE_HISTORY ADD CONSTRAINT ACTSTH_PK PRIMARY KEY (ACTIVITY_STATE_HISTORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).TASK_STATE_HISTORY ADD CONSTRAINT TSKSTH_PK PRIMARY KEY (TASK_STATE_HISTORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CATEGORY ADD CONSTRAINT REQCAT_PK PRIMARY KEY (REQUEST_CATEGORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).FILE_CLASSIFICATION ADD CONSTRAINT FILECLS_PK PRIMARY KEY (FILE_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).FILE_STREAM_CLASSIFICATION ADD CONSTRAINT FILESTRMCLS_PK PRIMARY KEY (FILE_STREAM_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_PK PRIMARY KEY (REQCHANGE_HISTORY_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).BUILD_CLASSIFICATION  ADD CONSTRAINT BLDCLS_PK PRIMARY KEY (BUILD_CLASS_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).BUILD_COMPILATION_RESULT ADD CONSTRAINT BLDCMPRES_PK PRIMARY KEY (BUILD_COMPRES_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).BUILD_UNIT_RESULT ADD CONSTRAINT BLDJUNRES_PK PRIMARY KEY (BUILD_UNITRES_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).BUILD_UNIT_EVENT ADD CONSTRAINT BLDJUNEVT_PK PRIMARY KEY (BUILD_UNIT_EVENT_ID) ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).UNIT_TEST_RESULT ADD CONSTRAINT BLDJUNTST_PK PRIMARY KEY (UNIT_TEST_RESULT_ID) 	ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).JOB ADD CONSTRAINT JOB_PK PRIMARY KEY (JOB_ID) 	ON  VNF_IDX
GO

ALTER TABLE $(NF_SCHEMA).JOB_RESULT ADD CONSTRAINT JOBRES_PK PRIMARY KEY (JOB_RESULT_ID) 	ON  VNF_IDX
GO

-- FOREIGN KEY CONSTRAINTS

ALTER TABLE $(NF_SCHEMA).ACTIVITY_DETAIL ADD CONSTRAINT ACTDET_FK1 FOREIGN KEY (ACTIVITY_ID) 
REFERENCES $(NF_SCHEMA).ACTIVITY (ACTIVITY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK1 FOREIGN KEY (TASK_ID)
REFERENCES $(NF_SCHEMA).TASK (TASK_ID)
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK2 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK3 FOREIGN KEY (FAILED_BUILD)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK4 FOREIGN KEY (VALIDATION_BUILD)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK5 FOREIGN KEY (NOTEST_BUILD)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK6 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK7 FOREIGN KEY (ACTIVITY_CLASS_ID)
REFERENCES $(NF_SCHEMA).ACTIVITY_CLASSIFICATION (ACTIVITY_CLASS_ID)	
GO

ALTER TABLE $(NF_SCHEMA).ACTIVITY ADD CONSTRAINT ACTIVITY_FK8 FOREIGN KEY (FILE_STREAM_ID)
REFERENCES $(NF_SCHEMA).FILE_STREAM (FILE_STREAM_ID)	
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_ACTIVITY_LOOKUP ADD CONSTRAINT REQACT_FK1 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).REQUEST_ACTIVITY_LOOKUP ADD CONSTRAINT REQACT_FK2 FOREIGN KEY (ACTIVITY_ID)
REFERENCES $(NF_SCHEMA).ACTIVITY (ACTIVITY_ID)	
GO

ALTER TABLE $(NF_SCHEMA).COMPONENT ADD CONSTRAINT COMPONENT_FK1 FOREIGN KEY (PRODUCT_ID)
REFERENCES $(NF_SCHEMA).PRODUCT (PRODUCT_ID)
GO

ALTER TABLE $(NF_SCHEMA).COMPONENT ADD CONSTRAINT COMPONENT_FK3 FOREIGN KEY (COMPONENT_CLASS_ID)
REFERENCES $(NF_SCHEMA).COMPONENT_CLASSIFICATION(COMPONENT_CLASS_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).PROJECT_COMPONENT_LOOKUP ADD CONSTRAINT PRJCOMP_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).PROJECT_COMPONENT_LOOKUP ADD CONSTRAINT PRJCOMP_FK2 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)	
GO

ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK2 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK3 FOREIGN KEY (BASELINE_ID)
REFERENCES $(NF_SCHEMA).PROJECT_BASELINE (BASELINE_ID)
GO

ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK4 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK5 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK6 FOREIGN KEY (PROJECT_TYPE_ID)
REFERENCES $(NF_SCHEMA).PROJECT_TYPE (PROJECT_TYPE_ID)
GO

ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK7 FOREIGN KEY (BUILD_CLASS_ID)
REFERENCES $(NF_SCHEMA).BUILD_CLASSIFICATION (BUILD_CLASS_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK8 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).BUILD ADD CONSTRAINT BUILD_FK9 FOREIGN KEY (TEAM_ID)
REFERENCES $(NF_SCHEMA).TEAM (TEAM_ID)	 	
GO
		
ALTER TABLE $(NF_SCHEMA).PROJECT_DETAIL ADD CONSTRAINT PROJECT_DETAIL_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK1 FOREIGN KEY (PLANNED_ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK2 FOREIGN KEY (ACTUAL_ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK3 FOREIGN KEY (RELEASE_ID)
REFERENCES $(NF_SCHEMA).RELEASE (RELEASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK4 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK5 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK7 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT ADD CONSTRAINT REQUIREMENT_FK8 FOREIGN KEY (REQUIREMENT_CLASS_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT_CLASSIFICATION (REQUIREMENT_CLASS_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REVISION_HISTORY ADD CONSTRAINT REQREV_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REVISION_HISTORY ADD CONSTRAINT REQREV_FK2 FOREIGN KEY (RESOURCE_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)	
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE ADD CONSTRAINT RESOURCE_FK1 FOREIGN KEY (POOL_ID)
REFERENCES $(NF_SCHEMA).POOL (POOL_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE ADD CONSTRAINT TESTSUITE_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE ADD CONSTRAINT TESTSUITE_FK2 FOREIGN KEY (CONFIGURATION_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION (CONFIGURATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE ADD CONSTRAINT TESTSUITE_FK3 FOREIGN KEY (ASSETREGISTRY_ID)
REFERENCES $(NF_SCHEMA).ASSETREGISTRY (ASSETREGISTRY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE ADD CONSTRAINT TESTSUITE_FK4 FOREIGN KEY (TESTSUITE_CLASS_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE_CLASSIFICATION (TESTSUITE_CLASS_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITE ADD CONSTRAINT TESTSUITE_FK5 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)		
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK2 FOREIGN KEY (BUILD_ID)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK3 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK4 FOREIGN KEY (TESTTYPE_ID)
REFERENCES $(NF_SCHEMA).TESTTYPE (TESTTYPE_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK5 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK6 FOREIGN KEY (EXECRES_CLASS_ID)
REFERENCES $(NF_SCHEMA).EXECRESULT_CLASSIFICATION (EXECRES_CLASS_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_RESULT ADD CONSTRAINT EXECRES_FK7 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)		
GO
	
ALTER TABLE $(NF_SCHEMA).ITERATION ADD CONSTRAINT ITERATION_FK1 FOREIGN KEY (ASSETREGISTRY_ID)
REFERENCES $(NF_SCHEMA).ASSETREGISTRY (ASSETREGISTRY_ID)
GO
				
ALTER TABLE $(NF_SCHEMA).ITERATION ADD CONSTRAINT ITERATION_FK4 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)	
GO

ALTER TABLE $(NF_SCHEMA).RELEASE ADD CONSTRAINT RELEASE_FK1 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).RELEASE ADD CONSTRAINT RELEASE_FK2 FOREIGN KEY (PRODUCT_ID)
REFERENCES $(NF_SCHEMA).PRODUCT (PRODUCT_ID)
GO

ALTER TABLE $(NF_SCHEMA).RELEASE ADD CONSTRAINT RELEASE_FK3 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO

ALTER TABLE $(NF_SCHEMA).PROJECT ADD CONSTRAINT PROJECT_FK1 FOREIGN KEY (PROJECT_MANAGER)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT ADD CONSTRAINT PROJECT_FK2 FOREIGN KEY (PROJECT_CATEGORY_ID)
REFERENCES $(NF_SCHEMA).PROJECT_CATEGORY (PROJECT_CATEGORY_ID)	
GO

ALTER TABLE $(NF_SCHEMA).PROJECT ADD CONSTRAINT PROJECT_FK3 FOREIGN KEY (PROJECT_CLASS_ID)
REFERENCES $(NF_SCHEMA).PROJECT_CLASSIFICATION (PROJECT_CLASS_ID)	
GO

ALTER TABLE $(NF_SCHEMA).TASK ADD CONSTRAINT TASK_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TASK ADD CONSTRAINT TASK_FK2 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO

ALTER TABLE $(NF_SCHEMA).TASK ADD CONSTRAINT TASK_FK3 FOREIGN KEY (TASK_CATEGORY_ID)
REFERENCES $(NF_SCHEMA).TASK_CATEGORY (TASK_CATEGORY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TASK ADD CONSTRAINT TASK_FK4 FOREIGN KEY (TASK_CLASS_ID)
REFERENCES $(NF_SCHEMA).TASK_CLASSIFICATION (TASK_CLASS_ID)	
GO

ALTER TABLE $(NF_SCHEMA).TASK ADD CONSTRAINT TASK_FK5 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)	
GO

ALTER TABLE $(NF_SCHEMA).TASK_DETAIL ADD CONSTRAINT TASK_DETAIL_FK1 FOREIGN KEY (TASK_ID)
REFERENCES $(NF_SCHEMA).TASK (TASK_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).PROJECT_HIERARCHY ADD CONSTRAINT PROJECTHIER_FK1 FOREIGN KEY (PARENT_PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_HIERARCHY ADD CONSTRAINT PROJECTHIER_FK2 FOREIGN KEY (CHILD_PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_DETAIL ADD CONSTRAINT PROJECTDT_FK1 FOREIGN KEY (CURRENCY_ID)
REFERENCES $(NF_SCHEMA).CURRENCY (CURRENCY_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_TYPE ADD CONSTRAINT PRJTYPE_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_WORKCONFIGURATION ADD CONSTRAINT PRJWKCFG_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_WORKCONFIGURATION ADD CONSTRAINT PRJWKCFG_FK2 FOREIGN KEY (PROJECT_TYPE_ID)
REFERENCES $(NF_SCHEMA).PROJECT_TYPE (PROJECT_TYPE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_CATEGORY ADD CONSTRAINT PRJCAT_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PHASE ADD CONSTRAINT PRJPHASE_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_ROLE ADD CONSTRAINT PRJROLE_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_ROLE ADD CONSTRAINT PRJROLE_FK2 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_ROLE_MEMBER_LOOKUP ADD CONSTRAINT PRJROLELK_FK1 FOREIGN KEY (PROJECT_ROLE_ID)
REFERENCES $(NF_SCHEMA).PROJECT_ROLE (PROJECT_ROLE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_ROLE_MEMBER_LOOKUP ADD CONSTRAINT PRJROLELK_FK2 FOREIGN KEY (RESOURCE_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TASK_REQUIREMENT_LOOKUP ADD CONSTRAINT TSKREQ_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).TASK_REQUIREMENT_LOOKUP ADD CONSTRAINT TSKREQ_FK2 FOREIGN KEY (TASK_ID)
REFERENCES $(NF_SCHEMA).TASK (TASK_ID)
GO

ALTER TABLE $(NF_SCHEMA).CONFIGURATION ADD CONSTRAINT CONFIGURATION_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).CONFIGURATION ADD CONSTRAINT CONFIGURATION_FK2 FOREIGN KEY (CONFIGURATION_CLASS_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION_CLASSIFICATION (CONFIGURATION_CLASS_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).CONFIGURATION ADD CONSTRAINT CONFIGURATION_FK3 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO

ALTER TABLE $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE_LOOKUP ADD CONSTRAINT CFGATTR_ATTR_FK1 FOREIGN KEY (CONFIGURATION_ATTRIBUTE_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE (CONFIGURATION_ATTRIBUTE_ID)
GO

ALTER TABLE $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE_LOOKUP ADD CONSTRAINT CFGATTR_ATTR_FK2 FOREIGN KEY (CONFIGURATION_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION (CONFIGURATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_ITERATION_LOOKUP ADD CONSTRAINT TSTITER_FK1 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_ITERATION_LOOKUP ADD CONSTRAINT TSTITER_FK2 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN ADD CONSTRAINT TESTPLAN_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN ADD CONSTRAINT TESTPLAN_FK2 FOREIGN KEY (ASSETREGISTRY_ID)
REFERENCES $(NF_SCHEMA).ASSETREGISTRY (ASSETREGISTRY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTPLAN ADD CONSTRAINT TESTPLAN_FK3 FOREIGN KEY (TESTPLAN_CLASS_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN_CLASSIFICATION  (TESTPLAN_CLASS_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).TESTPLAN ADD CONSTRAINT TESTPLAN_FK4 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO
			
ALTER TABLE $(NF_SCHEMA).TESTPLAN_ITERATION_LOOKUP ADD CONSTRAINT TSPLNITER_FK1 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_ITERATION_LOOKUP ADD CONSTRAINT TSPLNITER_FK2 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE ADD CONSTRAINT TESTCASE_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE ADD CONSTRAINT TESTCASE_FK2 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTCASE ADD CONSTRAINT TESTCASE_FK3 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO
			
ALTER TABLE $(NF_SCHEMA).TESTCASE ADD CONSTRAINT TESTCASE_FK4 FOREIGN KEY (TESTCASE_CLASS_ID)
REFERENCES $(NF_SCHEMA).TESTCASE_CLASSIFICATION (TESTCASE_CLASS_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTCASE ADD CONSTRAINT TESTCASE_FK5 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO
		
ALTER TABLE $(NF_SCHEMA).TESTCASE_ITERATION_LOOKUP ADD CONSTRAINT TESTCITER_FK1 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_ITERATION_LOOKUP ADD CONSTRAINT TESTCITER_FK2 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTCASE_LOOKUP ADD CONSTRAINT REQTEST_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTCASE_LOOKUP ADD CONSTRAINT REQTEST_FK2 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTPLAN_LOOKUP ADD CONSTRAINT REQTESTP_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTPLAN_LOOKUP ADD CONSTRAINT REQTESTP_FK2 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTSUITE_LOOKUP ADD CONSTRAINT REQTESTS_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_TESTSUITE_LOOKUP ADD CONSTRAINT REQTESTS_FK2 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REQUIREMENT_LOOKUP ADD CONSTRAINT REQTREQ_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REQUIREMENT_LOOKUP ADD CONSTRAINT REQTREQ_FK2 FOREIGN KEY (CREQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).REQUIREMENT_HIERARCHY ADD CONSTRAINT REQHIER_FK1 FOREIGN KEY (PRED_REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_HIERARCHY ADD CONSTRAINT REQHIER_FK2 FOREIGN KEY (SUCC_REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK1 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK2 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK3 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK4 FOREIGN KEY (TESTTYPE_ID)
REFERENCES $(NF_SCHEMA).TESTTYPE (TESTTYPE_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK5 FOREIGN KEY (CONFIGURATION_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION (CONFIGURATION_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK7 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).EXECUTION_WORKITEM ADD CONSTRAINT EXECWKI_FK9 FOREIGN KEY (EXECWORKIT_CLASS_ID)
REFERENCES $(NF_SCHEMA).EXECWORKITEM_CLASSIFICATION (EXECWORKIT_CLASS_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_ITERATION_LOOKUP ADD CONSTRAINT EXWKIITER_FK1 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_ITERATION_LOOKUP ADD CONSTRAINT EXECWKITER_FK2 FOREIGN KEY (EXECWORKITEM_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_WORKITEM (EXECWORKITEM_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_EXECWRKITEM_LOOKUP ADD CONSTRAINT REQEXWKI_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_EXECWRKITEM_LOOKUP ADD CONSTRAINT REQEXECWK_FK2 FOREIGN KEY (EXECWORKITEM_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_WORKITEM (EXECWORKITEM_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_TESTSUITE_LOOKUP ADD CONSTRAINT EXWKITSU_FK1 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECWORKITEM_TESTSUITE_LOOKUP ADD CONSTRAINT EXECWKTSU_FK2 FOREIGN KEY (EXECWORKITEM_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_WORKITEM (EXECWORKITEM_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK10 FOREIGN KEY (BUILD_ID)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK11 FOREIGN KEY (PROJECT_CATEGORY_ID)
REFERENCES $(NF_SCHEMA).PROJECT_CATEGORY (PROJECT_CATEGORY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK12 FOREIGN KEY (TEAM_ID)
REFERENCES $(NF_SCHEMA).TEAM (TEAM_ID)	
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK13 FOREIGN KEY (PHASE_ID)
REFERENCES $(NF_SCHEMA).PHASE (PHASE_ID)	
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK2 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK3 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK5 FOREIGN KEY (RELEASE_ID)
REFERENCES $(NF_SCHEMA).RELEASE (RELEASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK6 FOREIGN KEY (FIXEDINRELEASE_ID)
REFERENCES $(NF_SCHEMA).RELEASE (RELEASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK7 FOREIGN KEY (REQUEST_CLASS_ID)
REFERENCES $(NF_SCHEMA).REQUEST_CLASSIFICATION (REQUEST_CLASS_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST ADD CONSTRAINT REQUEST_FK8 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_HIERARCHY ADD CONSTRAINT REQUHIST_FK1 FOREIGN KEY (PARENT_REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_HIERARCHY ADD CONSTRAINT REQUHIST_FK2 FOREIGN KEY (CHILD_REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).[FILE] ADD CONSTRAINT FILE_FK1 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).[FILE] ADD CONSTRAINT FILE_FK2 FOREIGN KEY (FILE_CLASS_ID)
REFERENCES $(NF_SCHEMA).FILE_CLASSIFICATION (FILE_CLASS_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_VERSION ADD CONSTRAINT FILE_VERSION_FK1 FOREIGN KEY (FILE_ID)
REFERENCES $(NF_SCHEMA).[FILE] (FILE_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_VERSION ADD CONSTRAINT FILE_VERSION_FK2 FOREIGN KEY (AUTHOR_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_VERSION ADD CONSTRAINT FILE_VERSION_FK3 FOREIGN KEY (ACTIVITY_ID)
REFERENCES $(NF_SCHEMA).ACTIVITY (ACTIVITY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_VERSION ADD CONSTRAINT FILE_VERSION_FK4 FOREIGN KEY (FILE_STREAM_ID)
REFERENCES $(NF_SCHEMA).FILE_STREAM (FILE_STREAM_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_VERSION ADD CONSTRAINT FILE_FK5 FOREIGN KEY (FILE_CLASS_ID)
REFERENCES $(NF_SCHEMA).FILE_CLASSIFICATION (FILE_CLASS_ID)						
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_BASELINE ADD CONSTRAINT FBASE_FK1 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_BASELINE_ACTIVITY_LOOKUP ADD CONSTRAINT FBACT_FK1 FOREIGN KEY (FILE_BASELINE_ID)
REFERENCES $(NF_SCHEMA).FILE_BASELINE(FILE_BASELINE_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_BASELINE_ACTIVITY_LOOKUP ADD CONSTRAINT FBACT_FK2 FOREIGN KEY (ACTIVITY_ID)
REFERENCES $(NF_SCHEMA).ACTIVITY (ACTIVITY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).FILE_STREAM ADD CONSTRAINT FSTREAM_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).FILE_STREAM ADD CONSTRAINT FSTREAM_FK2 FOREIGN KEY (FILE_STREAM_CLASS_ID)
REFERENCES $(NF_SCHEMA).FILE_STREAM_CLASSIFICATION (FILE_STREAM_CLASS_ID)		
GO

ALTER TABLE $(NF_SCHEMA).CONFIG_EXECUTIONRES_LOOKUP ADD CONSTRAINT CFGEXECRES_FK1 FOREIGN KEY (CONFIGURATION_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION (CONFIGURATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).CONFIG_EXECUTIONRES_LOOKUP ADD CONSTRAINT CFGEXECRES_FK2 FOREIGN KEY (EXECUTION_RESULT_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_RESULT (EXECUTION_RESULT_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_FK1 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_FK2 FOREIGN KEY (BUILD_ID)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_FK3 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTSUITELOG ADD CONSTRAINT TESTSUITELOG_FK4 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)	
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG ADD CONSTRAINT  TESTSUITELOG_FK5 FOREIGN KEY (TESTSUITELOG_CLASS_ID)
REFERENCES $(NF_SCHEMA).TESTSUITELOG_CLASSIFICATION (TESTSUITELOG_CLASS_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG_EXECRESULT_LOOKUP ADD CONSTRAINT STESEXECR_FK1 FOREIGN KEY (TESTSUITELOG_ID)
REFERENCES $(NF_SCHEMA).TESTSUITELOG (TESTSUITELOG_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITELOG_EXECRESULT_LOOKUP ADD CONSTRAINT STESEXECR_FK2 FOREIGN KEY (EXECUTION_RESULT_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_RESULT (EXECUTION_RESULT_ID)
GO

ALTER TABLE $(NF_SCHEMA).TASK_REQUEST_LOOKUP ADD CONSTRAINT TSKISSU_FK1 FOREIGN KEY (TASK_ID)
REFERENCES $(NF_SCHEMA).TASK (TASK_ID)
GO

ALTER TABLE $(NF_SCHEMA).TASK_REQUEST_LOOKUP ADD CONSTRAINT TSKISSU_FK2 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REQUEST_LOOKUP ADD CONSTRAINT REQIREQ_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_REQUEST_LOOKUP ADD CONSTRAINT REQREQ_FK2 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CUSTOMER_LOOKUP ADD CONSTRAINT REQUCULK_FK1 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_STATE_HISTORY ADD CONSTRAINT REQSTATEHIST_FK1 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID) 
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CUSTOMER_LOOKUP ADD CONSTRAINT REQUCULK_FK2 FOREIGN KEY (CUSTOMER_ID)
REFERENCES $(NF_SCHEMA).CUSTOMER (CUSTOMER_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_CUSTOMER_LOOKUP ADD CONSTRAINT REQUICLK_FK1 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUIREMENT_CUSTOMER_LOOKUP ADD CONSTRAINT REQUICLK_FK2 FOREIGN KEY (CUSTOMER_ID)
REFERENCES $(NF_SCHEMA).CUSTOMER (CUSTOMER_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECRES_REQUEST_LOOKUP ADD CONSTRAINT EXECRESREQ_FK1 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECRES_REQUEST_LOOKUP ADD CONSTRAINT EXECRESREQ_FK2 FOREIGN KEY (EXECUTION_RESULT_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_RESULT (EXECUTION_RESULT_ID)
GO

ALTER TABLE $(NF_SCHEMA).RISK ADD CONSTRAINT RISK_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).RISK ADD CONSTRAINT RISK_FK2 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).RISK ADD CONSTRAINT RISK_FK3 FOREIGN KEY (RELEASE_ID)
REFERENCES $(NF_SCHEMA).RELEASE (RELEASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).RISK ADD CONSTRAINT RISK_FK4 FOREIGN KEY (ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).RISK ADD CONSTRAINT RISK_FK5 FOREIGN KEY (REQUIREMENT_ID)
REFERENCES $(NF_SCHEMA).REQUIREMENT (REQUIREMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).RISK_STATE_HISTORY ADD CONSTRAINT RISKSTATEHIST_FK1 FOREIGN KEY (RISK_ID)
REFERENCES $(NF_SCHEMA).RISK (RISK_ID)
GO

ALTER TABLE $(NF_SCHEMA).FACTOR ADD CONSTRAINT FACTOR_FK1 FOREIGN KEY (RISK_ID)
REFERENCES $(NF_SCHEMA).RISK (RISK_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_BASELINE ADD CONSTRAINT PRJBASELINE_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_BASELINE ADD CONSTRAINT PRJBASELINE_FK2 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_BASELINE ADD CONSTRAINT PRJBASELINE_FK3 FOREIGN KEY (FILE_STREAM_ID)
REFERENCES $(NF_SCHEMA).FILE_STREAM (FILE_STREAM_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJ_BASELINE_BASELINE_LOOKUP ADD CONSTRAINT PRJBSLTOBSL_FK1 FOREIGN KEY (BASELINE_ID)
REFERENCES $(NF_SCHEMA).PROJECT_BASELINE (BASELINE_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJ_BASELINE_BASELINE_LOOKUP ADD CONSTRAINT PRJBSLTOBSL_FK2 FOREIGN KEY (COMPBASELINE_ID)
REFERENCES $(NF_SCHEMA).PROJECT_BASELINE (BASELINE_ID)
GO

ALTER TABLE $(NF_SCHEMA).COMMENT ADD CONSTRAINT COMMENT_FK1 FOREIGN KEY (RESPONSE_COMMENT_ID)
REFERENCES $(NF_SCHEMA).COMMENT (COMMENT_ID)
GO

ALTER TABLE $(NF_SCHEMA).COMMENT ADD CONSTRAINT COMMENT_FK2 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO

ALTER TABLE $(NF_SCHEMA).COMMENT ADD CONSTRAINT COMMENT_FK3 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)
GO

ALTER TABLE $(NF_SCHEMA).COMMENT ADD CONSTRAINT COMMENT_FK4 FOREIGN KEY (TASK_ID)
REFERENCES $(NF_SCHEMA).TASK (TASK_ID)
GO

ALTER TABLE $(NF_SCHEMA).COMMENT ADD CONSTRAINT COMMENT_FK5 FOREIGN KEY (ACTIVITY_ID)
REFERENCES $(NF_SCHEMA).ACTIVITY (ACTIVITY_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_WORKCONFIG_HIERARCHY ADD CONSTRAINT PRJWCFGH_FK1 FOREIGN KEY(PARENT_WKCFG_ID)
REFERENCES $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (PROJECT_WKCFG_ID)
GO

ALTER TABLE $(NF_SCHEMA).PROJECT_WORKCONFIG_HIERARCHY ADD CONSTRAINT PRJWCFGH_FK2 FOREIGN KEY(CHILD_WKCFG_ID)
REFERENCES $(NF_SCHEMA).PROJECT_WORKCONFIGURATION (PROJECT_WKCFG_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECRES_EXECWKITEM_LOOKUP ADD CONSTRAINT EXECRESWK_FK1 FOREIGN KEY (EXECUTION_RESULT_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_RESULT (EXECUTION_RESULT_ID)
GO

ALTER TABLE $(NF_SCHEMA).EXECRES_EXECWKITEM_LOOKUP ADD CONSTRAINT EXECRESWK_FK2 FOREIGN KEY (EXECWORKITEM_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_WORKITEM (EXECWORKITEM_ID)
GO

ALTER TABLE $(NF_SCHEMA).CONFIG_EXECUTIONWORKITM_LOOKUP  ADD CONSTRAINT CFGEXECWK_FK1 FOREIGN KEY (CONFIGURATION_ID)
REFERENCES $(NF_SCHEMA).CONFIGURATION (CONFIGURATION_ID)
GO

ALTER TABLE $(NF_SCHEMA).CONFIG_EXECUTIONWORKITM_LOOKUP  ADD CONSTRAINT CFGEXECWK_FK2 FOREIGN KEY (EXECWORKITEM_ID)
REFERENCES $(NF_SCHEMA).EXECUTION_WORKITEM (EXECWORKITEM_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).TESTPLAN_CATEGORY_LOOKUP ADD CONSTRAINT TPLNCAT_FK1 FOREIGN KEY (TEST_CATEGORY_ID)
REFERENCES $(NF_SCHEMA).TEST_CATEGORY (TEST_CATEGORY_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_CATEGORY_LOOKUP ADD CONSTRAINT TPLNCAT_FK2 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_CATEGORY_LOOKUP ADD CONSTRAINT TCASECAT_FK1 FOREIGN KEY (TEST_CATEGORY_ID)
REFERENCES $(NF_SCHEMA).TEST_CATEGORY (TEST_CATEGORY_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTCASE_CATEGORY_LOOKUP ADD CONSTRAINT TCASECAT_FK2 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTCASE_LOOKUP ADD CONSTRAINT TSUTCASE_FK1 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTCASE_LOOKUP ADD CONSTRAINT TSUTCASE_FK2 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)		
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTSUITELOG_LOOKUP ADD CONSTRAINT TSUTSULG_FK1 FOREIGN KEY (TESTSUITE_ID)
REFERENCES $(NF_SCHEMA).TESTSUITE (TESTSUITE_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTSUITE_TESTSUITELOG_LOOKUP ADD CONSTRAINT TSUTSULG_FK2 FOREIGN KEY (TESTSUITELOG_ID)
REFERENCES $(NF_SCHEMA).TESTSUITELOG (TESTSUITELOG_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_TESTPLAN_HIERARCHY ADD CONSTRAINT TPLNPC_FK1 FOREIGN KEY (PARENT_TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_TESTPLAN_HIERARCHY ADD CONSTRAINT TPLNPC_FK2 FOREIGN KEY (CHILD_TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN (TESTPLAN_ID)
GO

ALTER TABLE $(NF_SCHEMA).TESTPLAN_TESTCASE_LOOKUP ADD CONSTRAINT TPLNTC_FK1 FOREIGN KEY (TESTPLAN_ID)
REFERENCES $(NF_SCHEMA).TESTPLAN(TESTPLAN_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TESTPLAN_TESTCASE_LOOKUP ADD CONSTRAINT TPLNTC_FK2 FOREIGN KEY (TESTCASE_ID)
REFERENCES $(NF_SCHEMA).TESTCASE (TESTCASE_ID)	
GO

ALTER TABLE $(NF_SCHEMA).LAB_RESOURCE ADD CONSTRAINT LABRES_FK1 FOREIGN KEY (RESOURCE_GROUP_ID)
REFERENCES $(NF_SCHEMA).RESOURCE_GROUP (RESOURCE_GROUP_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).LAB_RESOURCE ADD CONSTRAINT LABRES_FK2 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO

ALTER TABLE $(NF_SCHEMA).RESOURCE_GROUP ADD CONSTRAINT RESGRP_FK1 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).RESERVATION ADD CONSTRAINT RESERV_FK1 FOREIGN KEY (LAB_RESOURCE_ID)
REFERENCES $(NF_SCHEMA).LAB_RESOURCE (LAB_RESOURCE_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).RESERVATION ADD CONSTRAINT RESERV_FK2 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)	
GO
	
ALTER TABLE $(NF_SCHEMA).ACTIVITY_STATE_HISTORY ADD CONSTRAINT ACTSTH_FK1 FOREIGN KEY (ACTIVITY_ID)
REFERENCES $(NF_SCHEMA).ACTIVITY (ACTIVITY_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).TASK_STATE_HISTORY ADD CONSTRAINT TSKSTH_FK1 FOREIGN KEY (TASK_ID)
REFERENCES $(NF_SCHEMA).TASK (TASK_ID)
GO
	
ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK1 FOREIGN KEY (REQUEST_CLASS_ID)
REFERENCES $(NF_SCHEMA).REQUEST_CLASSIFICATION (REQUEST_CLASS_ID)
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK2 FOREIGN KEY (REQUEST_ID)
REFERENCES $(NF_SCHEMA).REQUEST (REQUEST_ID)                          
GO

ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK3 FOREIGN KEY (PREV_TEAM_ID)
REFERENCES $(NF_SCHEMA).TEAM (TEAM_ID)    
GO
                       
ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK4 FOREIGN KEY (PREV_REQUEST_CATEGORY_ID)
REFERENCES $(NF_SCHEMA).REQUEST_CATEGORY (REQUEST_CATEGORY_ID)  
GO
              
ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK5 FOREIGN KEY (PREV_ITERATION_ID)
REFERENCES $(NF_SCHEMA).ITERATION (ITERATION_ID)     
GO
                                       
ALTER TABLE $(NF_SCHEMA).REQUEST_CHANGE_HISTORY ADD CONSTRAINT REQCGNGH_FK6 FOREIGN KEY (PREV_OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).BUILD_COMPILATION_RESULT ADD CONSTRAINT BLDCMPRES_FK1 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).BUILD_COMPILATION_RESULT ADD CONSTRAINT BLDCMPRES_FK2 FOREIGN KEY (BUILD_ID)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).BUILD_UNIT_RESULT ADD CONSTRAINT BLDJUNRES_FK1 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).BUILD_UNIT_RESULT ADD CONSTRAINT BLDJUNRES_FK2 FOREIGN KEY (BUILD_ID)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).BUILD_UNIT_EVENT ADD CONSTRAINT BLDJUNEVT_FK1 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).BUILD_UNIT_EVENT ADD CONSTRAINT BLDJUNEVT_FK2 FOREIGN KEY (BUILD_ID)
REFERENCES $(NF_SCHEMA).BUILD (BUILD_ID)
GO
				
ALTER TABLE $(NF_SCHEMA).UNIT_TEST_RESULT ADD CONSTRAINT BLDJUNTST_FK1 FOREIGN KEY (COMPONENT_ID)
REFERENCES $(NF_SCHEMA).COMPONENT (COMPONENT_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).UNIT_TEST_RESULT ADD CONSTRAINT BLDJUNTST_FK2 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).UNIT_TEST_RESULT ADD CONSTRAINT BLDJUNTST_FK3 FOREIGN KEY (TEAM_ID)
REFERENCES $(NF_SCHEMA).TEAM(TEAM_ID)
GO

ALTER TABLE $(NF_SCHEMA).JOB ADD CONSTRAINT JOB_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)
GO
		
ALTER TABLE $(NF_SCHEMA).JOB ADD CONSTRAINT JOB_FK2 FOREIGN KEY (PROJECT_ID)
REFERENCES $(NF_SCHEMA).PROJECT (PROJECT_ID)		
GO
		
ALTER TABLE $(NF_SCHEMA).JOB_RESULT ADD CONSTRAINT JOBRES_FK1 FOREIGN KEY (OWNER_ID)
REFERENCES $(NF_SCHEMA).RESOURCE (RESOURCE_ID)		
GO
		
ALTER TABLE $(NF_SCHEMA).JOB_RESULT ADD CONSTRAINT JOBRES_FK2 FOREIGN KEY (JOB_ID)
REFERENCES $(NF_SCHEMA).JOB (JOB_ID)	
GO
		
ALTER TABLE $(NF_SCHEMA).JOB_RESULT ADD CONSTRAINT JOBRES_FK3 FOREIGN KEY (LAB_RESOURCE_ID)
REFERENCES $(NF_SCHEMA).LAB_RESOURCE (LAB_RESOURCE_ID)		
GO
		
		
--LOOKUP HIERARCHY TRIGGERS
   
CREATE TRIGGER TRG_REQCUSTD
    ON $(NF_SCHEMA).REQUEST

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUEST_CUSTOMER_LOOKUP  WHERE  REQUEST_ID IN 
  (SELECT  REQUEST_ID FROM INSERTED )
 END
GO
    
CREATE TRIGGER TRG_REQREQUI
    ON $(NF_SCHEMA).REQUEST

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUIREMENT_REQUEST_LOOKUP  WHERE  REQUEST_ID IN 
  (SELECT  REQUEST_ID FROM INSERTED )
 END
GO
    
CREATE TRIGGER TRG_REQTASK
    ON $(NF_SCHEMA).REQUEST

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TASK_REQUEST_LOOKUP  WHERE  REQUEST_ID IN 
  (SELECT  REQUEST_ID FROM INSERTED )
 END
GO
    
CREATE TRIGGER TRG_REQLOG
    ON $(NF_SCHEMA).REQUEST

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).EXECRES_REQUEST_LOOKUP  WHERE  REQUEST_ID IN 
  (SELECT  REQUEST_ID FROM INSERTED )
 END
GO
    
CREATE TRIGGER TRG_REQREQ
    ON $(NF_SCHEMA).REQUEST

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUEST_HIERARCHY  WHERE  PARENT_REQUEST_ID IN 
  (SELECT  PARENT_REQUEST_ID FROM INSERTED )
 END
GO
    

CREATE TRIGGER TRG_EXWKIITDD
    ON $(NF_SCHEMA).EXECUTION_WORKITEM

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).EXECWORKITEM_ITERATION_LOOKUP  WHERE  EXECWORKITEM_ID IN 
  (SELECT  EXECWORKITEM_ID FROM INSERTED )
 END
GO
    
    
CREATE TRIGGER TRG_EXWKITSUD
    ON $(NF_SCHEMA).EXECUTION_WORKITEM

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).EXECWORKITEM_TESTSUITE_LOOKUP  WHERE  EXECWORKITEM_ID IN 
  (SELECT  EXECWORKITEM_ID FROM INSERTED )
 END
GO
    
CREATE TRIGGER TRG_CONFATTRD
    ON $(NF_SCHEMA).CONFIGURATION

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).CONFIGURATION_ATTRIBUTE_LOOKUP  WHERE  CONFIGURATION_ID IN 
  (SELECT  CONFIGURATION_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_CONFTLGD
    ON $(NF_SCHEMA).CONFIGURATION

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).CONFIG_EXECUTIONRES_LOOKUP  WHERE  CONFIGURATION_ID IN 
  (SELECT  CONFIGURATION_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_PRJBSLND
    ON $(NF_SCHEMA).PROJECT_BASELINE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).PROJ_BASELINE_BASELINE_LOOKUP  WHERE  BASELINE_ID IN 
  (SELECT  BASELINE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_PRJROLED
    ON $(NF_SCHEMA).PROJECT_ROLE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).PROJECT_ROLE_MEMBER_LOOKUP  WHERE  PROJECT_ROLE_ID IN 
  (SELECT  PROJECT_ROLE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_REQUITSTCD
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUIREMENT_EXECWRKITEM_LOOKUP  WHERE  REQUIREMENT_ID IN 
  (SELECT  REQUIREMENT_ID FROM INSERTED )
 END
GO
    
CREATE TRIGGER TRG_REQICUSTD
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUIREMENT_CUSTOMER_LOOKUP  WHERE  REQUIREMENT_ID IN 
  (SELECT  REQUIREMENT_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_REQIREQUID
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUIREMENT_REQUIREMENT_LOOKUP  WHERE  REQUIREMENT_ID IN 
  (SELECT  REQUIREMENT_ID FROM INSERTED )
 END
GO
        
CREATE TRIGGER TRG_REQITSTCD
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUIREMENT_TESTCASE_LOOKUP  WHERE  REQUIREMENT_ID IN 
  (SELECT  REQUIREMENT_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_REQITPLND
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUIREMENT_TESTPLAN_LOOKUP  WHERE  REQUIREMENT_ID IN 
  (SELECT  REQUIREMENT_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_REQITSUTD
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUIREMENT_TESTSUITE_LOOKUP  WHERE  REQUIREMENT_ID IN 
  (SELECT  REQUIREMENT_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TSLOG
    ON $(NF_SCHEMA).TESTSUITELOG

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTSUITELOG_EXECRESULT_LOOKUP  WHERE  TESTSUITELOG_ID IN 
  (SELECT  TESTSUITELOG_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TSKREQID
    ON $(NF_SCHEMA).REQUIREMENT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TASK_REQUIREMENT_LOOKUP  WHERE  REQUIREMENT_ID IN 
  (SELECT  REQUIREMENT_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TSCITERD
    ON $(NF_SCHEMA).TESTCASE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTCASE_ITERATION_LOOKUP  WHERE  TESTCASE_ID IN 
  (SELECT  TESTCASE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TPLNITERD
    ON $(NF_SCHEMA).TESTPLAN

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTPLAN_ITERATION_LOOKUP  WHERE  TESTPLAN_ID IN 
  (SELECT  TESTPLAN_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TSUTITERD
    ON $(NF_SCHEMA).TESTSUITE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTSUITE_ITERATION_LOOKUP  WHERE  TESTSUITE_ID IN 
  (SELECT  TESTSUITE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_PRJHIERD
    ON $(NF_SCHEMA).PROJECT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).PROJECT_HIERARCHY  WHERE  PARENT_PROJECT_ID IN 
  (SELECT  PARENT_PROJECT_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_PRJCOMPD
    ON $(NF_SCHEMA).PROJECT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).PROJECT_COMPONENT_LOOKUP  WHERE  PROJECT_ID IN 
  (SELECT  PROJECT_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_FBSACTD
    ON $(NF_SCHEMA).ACTIVITY

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).FILE_BASELINE_ACTIVITY_LOOKUP  WHERE  ACTIVITY_ID IN 
  (SELECT  ACTIVITY_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_REQACTD
    ON $(NF_SCHEMA).REQUEST

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).REQUEST_ACTIVITY_LOOKUP  WHERE  REQUEST_ID IN 
  (SELECT  REQUEST_ID FROM INSERTED )
 END
GO
  
CREATE TRIGGER TRG_EXERESWKIT
    ON $(NF_SCHEMA).EXECUTION_RESULT

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).EXECRES_EXECWKITEM_LOOKUP  WHERE  EXECUTION_RESULT_ID IN 
  (SELECT  EXECUTION_RESULT_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_CFGEXECWK
    ON $(NF_SCHEMA).EXECUTION_WORKITEM

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).CONFIG_EXECUTIONWORKITM_LOOKUP  WHERE  EXECWORKITEM_ID IN 
  (SELECT  EXECWORKITEM_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TPLNCAT
    ON $(NF_SCHEMA).TESTPLAN

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTPLAN_CATEGORY_LOOKUP  WHERE  TESTPLAN_ID IN 
  (SELECT  TESTPLAN_ID FROM INSERTED )
 END
GO
    
    
CREATE TRIGGER TRG_TCASECAT
    ON $(NF_SCHEMA).TESTCASE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTCASE_CATEGORY_LOOKUP  WHERE  TESTCASE_ID IN 
  (SELECT  TESTCASE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TSUTCASE
    ON $(NF_SCHEMA).TESTCASE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTSUITE_TESTCASE_LOOKUP  WHERE  TESTCASE_ID IN 
  (SELECT  TESTCASE_ID FROM INSERTED )
 END
GO
    
CREATE TRIGGER TRG_TSUTLG
    ON $(NF_SCHEMA).TESTSUITE

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTSUITE_TESTSUITELOG_LOOKUP  WHERE  TESTSUITE_ID IN 
  (SELECT  TESTSUITE_ID FROM INSERTED )
 END
GO

CREATE TRIGGER TRG_TPLNTCS
    ON $(NF_SCHEMA).TESTPLAN

    FOR UPDATE
AS
BEGIN 

  DELETE FROM $(NF_SCHEMA).TESTPLAN_TESTCASE_LOOKUP  WHERE  TESTPLAN_ID IN 
  (SELECT  TESTPLAN_ID FROM INSERTED )
 END
GO
            
